# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/distribution/v1beta1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from amino import amino_pb2 as amino_dot_amino__pb2
from cosmos.distribution.v1beta1 import distribution_pb2 as cosmos_dot_distribution_dot_v1beta1_dot_distribution__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$cosmos/distribution/v1beta1/tx.proto\x12\x1b\x63osmos.distribution.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x11\x61mino/amino.proto\x1a.cosmos/distribution/v1beta1/distribution.proto\"\xc8\x01\n\x15MsgSetWithdrawAddress\x12\x33\n\x11\x64\x65legator_address\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x32\n\x10withdraw_address\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString:F\x82\xe7\xb0*\x11\x64\x65legator_address\x8a\xe7\xb0*#cosmos-sdk/MsgModifyWithdrawAddress\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x1f\n\x1dMsgSetWithdrawAddressResponse\"\xd1\x01\n\x1aMsgWithdrawDelegatorReward\x12\x33\n\x11\x64\x65legator_address\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x33\n\x11validator_address\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString:I\x82\xe7\xb0*\x11\x64\x65legator_address\x8a\xe7\xb0*&cosmos-sdk/MsgWithdrawDelegationReward\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x86\x01\n\"MsgWithdrawDelegatorRewardResponse\x12`\n\x06\x61mount\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB5\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\"\x9d\x01\n\x1eMsgWithdrawValidatorCommission\x12\x33\n\x11validator_address\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString:F\x82\xe7\xb0*\x11validator_address\x8a\xe7\xb0*#cosmos-sdk/MsgWithdrawValCommission\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x8a\x01\n&MsgWithdrawValidatorCommissionResponse\x12`\n\x06\x61mount\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB5\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\"\xe1\x01\n\x14MsgFundCommunityPool\x12`\n\x06\x61mount\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB5\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12+\n\tdepositor\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString::\x82\xe7\xb0*\tdepositor\x8a\xe7\xb0*\x1f\x63osmos-sdk/MsgFundCommunityPool\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x1e\n\x1cMsgFundCommunityPoolResponse\"\xba\x01\n\x0fMsgUpdateParams\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12>\n\x06params\x18\x02 \x01(\x0b\x32#.cosmos.distribution.v1beta1.ParamsB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01::\x82\xe7\xb0*\tauthority\x8a\xe7\xb0*\'cosmos-sdk/distribution/MsgUpdateParams\"\x19\n\x17MsgUpdateParamsResponse\"\xf4\x01\n\x15MsgCommunityPoolSpend\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x11\n\trecipient\x18\x02 \x01(\t\x12`\n\x06\x61mount\x18\x03 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB5\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins:9\x82\xe7\xb0*\tauthority\x8a\xe7\xb0*&cosmos-sdk/distr/MsgCommunityPoolSpend\"\x1f\n\x1dMsgCommunityPoolSpendResponse2\xca\x06\n\x03Msg\x12\x84\x01\n\x12SetWithdrawAddress\x12\x32.cosmos.distribution.v1beta1.MsgSetWithdrawAddress\x1a:.cosmos.distribution.v1beta1.MsgSetWithdrawAddressResponse\x12\x93\x01\n\x17WithdrawDelegatorReward\x12\x37.cosmos.distribution.v1beta1.MsgWithdrawDelegatorReward\x1a?.cosmos.distribution.v1beta1.MsgWithdrawDelegatorRewardResponse\x12\x9f\x01\n\x1bWithdrawValidatorCommission\x12;.cosmos.distribution.v1beta1.MsgWithdrawValidatorCommission\x1a\x43.cosmos.distribution.v1beta1.MsgWithdrawValidatorCommissionResponse\x12\x81\x01\n\x11\x46undCommunityPool\x12\x31.cosmos.distribution.v1beta1.MsgFundCommunityPool\x1a\x39.cosmos.distribution.v1beta1.MsgFundCommunityPoolResponse\x12r\n\x0cUpdateParams\x12,.cosmos.distribution.v1beta1.MsgUpdateParams\x1a\x34.cosmos.distribution.v1beta1.MsgUpdateParamsResponse\x12\x84\x01\n\x12\x43ommunityPoolSpend\x12\x32.cosmos.distribution.v1beta1.MsgCommunityPoolSpend\x1a:.cosmos.distribution.v1beta1.MsgCommunityPoolSpendResponse\x1a\x05\x80\xe7\xb0*\x01\x42\x37Z1github.com/cosmos/cosmos-sdk/x/distribution/types\xa8\xe2\x1e\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.distribution.v1beta1.tx_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1github.com/cosmos/cosmos-sdk/x/distribution/types\250\342\036\001'
  _MSGSETWITHDRAWADDRESS.fields_by_name['delegator_address']._options = None
  _MSGSETWITHDRAWADDRESS.fields_by_name['delegator_address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _MSGSETWITHDRAWADDRESS.fields_by_name['withdraw_address']._options = None
  _MSGSETWITHDRAWADDRESS.fields_by_name['withdraw_address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _MSGSETWITHDRAWADDRESS._options = None
  _MSGSETWITHDRAWADDRESS._serialized_options = b'\202\347\260*\021delegator_address\212\347\260*#cosmos-sdk/MsgModifyWithdrawAddress\350\240\037\000\210\240\037\000'
  _MSGWITHDRAWDELEGATORREWARD.fields_by_name['delegator_address']._options = None
  _MSGWITHDRAWDELEGATORREWARD.fields_by_name['delegator_address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _MSGWITHDRAWDELEGATORREWARD.fields_by_name['validator_address']._options = None
  _MSGWITHDRAWDELEGATORREWARD.fields_by_name['validator_address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _MSGWITHDRAWDELEGATORREWARD._options = None
  _MSGWITHDRAWDELEGATORREWARD._serialized_options = b'\202\347\260*\021delegator_address\212\347\260*&cosmos-sdk/MsgWithdrawDelegationReward\350\240\037\000\210\240\037\000'
  _MSGWITHDRAWDELEGATORREWARDRESPONSE.fields_by_name['amount']._options = None
  _MSGWITHDRAWDELEGATORREWARDRESPONSE.fields_by_name['amount']._serialized_options = b'\310\336\037\000\250\347\260*\001\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _MSGWITHDRAWVALIDATORCOMMISSION.fields_by_name['validator_address']._options = None
  _MSGWITHDRAWVALIDATORCOMMISSION.fields_by_name['validator_address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _MSGWITHDRAWVALIDATORCOMMISSION._options = None
  _MSGWITHDRAWVALIDATORCOMMISSION._serialized_options = b'\202\347\260*\021validator_address\212\347\260*#cosmos-sdk/MsgWithdrawValCommission\350\240\037\000\210\240\037\000'
  _MSGWITHDRAWVALIDATORCOMMISSIONRESPONSE.fields_by_name['amount']._options = None
  _MSGWITHDRAWVALIDATORCOMMISSIONRESPONSE.fields_by_name['amount']._serialized_options = b'\310\336\037\000\250\347\260*\001\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _MSGFUNDCOMMUNITYPOOL.fields_by_name['amount']._options = None
  _MSGFUNDCOMMUNITYPOOL.fields_by_name['amount']._serialized_options = b'\310\336\037\000\250\347\260*\001\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _MSGFUNDCOMMUNITYPOOL.fields_by_name['depositor']._options = None
  _MSGFUNDCOMMUNITYPOOL.fields_by_name['depositor']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _MSGFUNDCOMMUNITYPOOL._options = None
  _MSGFUNDCOMMUNITYPOOL._serialized_options = b'\202\347\260*\tdepositor\212\347\260*\037cosmos-sdk/MsgFundCommunityPool\350\240\037\000\210\240\037\000'
  _MSGUPDATEPARAMS.fields_by_name['authority']._options = None
  _MSGUPDATEPARAMS.fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _MSGUPDATEPARAMS.fields_by_name['params']._options = None
  _MSGUPDATEPARAMS.fields_by_name['params']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _MSGUPDATEPARAMS._options = None
  _MSGUPDATEPARAMS._serialized_options = b'\202\347\260*\tauthority\212\347\260*\'cosmos-sdk/distribution/MsgUpdateParams'
  _MSGCOMMUNITYPOOLSPEND.fields_by_name['authority']._options = None
  _MSGCOMMUNITYPOOLSPEND.fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _MSGCOMMUNITYPOOLSPEND.fields_by_name['amount']._options = None
  _MSGCOMMUNITYPOOLSPEND.fields_by_name['amount']._serialized_options = b'\310\336\037\000\250\347\260*\001\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _MSGCOMMUNITYPOOLSPEND._options = None
  _MSGCOMMUNITYPOOLSPEND._serialized_options = b'\202\347\260*\tauthority\212\347\260*&cosmos-sdk/distr/MsgCommunityPoolSpend'
  _MSG._options = None
  _MSG._serialized_options = b'\200\347\260*\001'
  _MSGSETWITHDRAWADDRESS._serialized_start=243
  _MSGSETWITHDRAWADDRESS._serialized_end=443
  _MSGSETWITHDRAWADDRESSRESPONSE._serialized_start=445
  _MSGSETWITHDRAWADDRESSRESPONSE._serialized_end=476
  _MSGWITHDRAWDELEGATORREWARD._serialized_start=479
  _MSGWITHDRAWDELEGATORREWARD._serialized_end=688
  _MSGWITHDRAWDELEGATORREWARDRESPONSE._serialized_start=691
  _MSGWITHDRAWDELEGATORREWARDRESPONSE._serialized_end=825
  _MSGWITHDRAWVALIDATORCOMMISSION._serialized_start=828
  _MSGWITHDRAWVALIDATORCOMMISSION._serialized_end=985
  _MSGWITHDRAWVALIDATORCOMMISSIONRESPONSE._serialized_start=988
  _MSGWITHDRAWVALIDATORCOMMISSIONRESPONSE._serialized_end=1126
  _MSGFUNDCOMMUNITYPOOL._serialized_start=1129
  _MSGFUNDCOMMUNITYPOOL._serialized_end=1354
  _MSGFUNDCOMMUNITYPOOLRESPONSE._serialized_start=1356
  _MSGFUNDCOMMUNITYPOOLRESPONSE._serialized_end=1386
  _MSGUPDATEPARAMS._serialized_start=1389
  _MSGUPDATEPARAMS._serialized_end=1575
  _MSGUPDATEPARAMSRESPONSE._serialized_start=1577
  _MSGUPDATEPARAMSRESPONSE._serialized_end=1602
  _MSGCOMMUNITYPOOLSPEND._serialized_start=1605
  _MSGCOMMUNITYPOOLSPEND._serialized_end=1849
  _MSGCOMMUNITYPOOLSPENDRESPONSE._serialized_start=1851
  _MSGCOMMUNITYPOOLSPENDRESPONSE._serialized_end=1882
  _MSG._serialized_start=1885
  _MSG._serialized_end=2727
# @@protoc_insertion_point(module_scope)



import logging

import pytest

from pyinjective.composer import Composer
from pyinjective.constant import Denom, Network


class TestComposer:

    @pytest.fixture
    def inj_usdt_market_id(self):
        return "0xa508cb32923323679f29a032c70342c147c17d0145625922b0ef22e955c844c0"

    def test_spot_order_creation_logs_market_data_loaded_info(self, caplog, inj_usdt_market_id):
        caplog.set_level(logging.INFO)

        composer = Composer(network=Network.devnet().string())

        composer.SpotOrder(
            market_id=inj_usdt_market_id,
            subaccount_id="",
            fee_recipient="",
            price=1.0,
            quantity=1.0,
        )

        expected_log_message_prefix = "Loaded market metadata for: 'Devnet Spot INJ/USDT'"
        expected_log_record = ("pyinjective.composer.Composer", logging.INFO, expected_log_message_prefix)
        assert(expected_log_record in caplog.record_tuples)

    def test_derivative_order_creation_logs_market_data_loaded_info(self, caplog, inj_usdt_market_id):
        caplog.set_level(logging.INFO)

        composer = Composer(network=Network.devnet().string())

        composer.DerivativeOrder(
            market_id=inj_usdt_market_id,
            subaccount_id="",
            fee_recipient="",
            price=1.0,
            quantity=1.0,
            leverage=1.0,
        )

        expected_log_message_prefix = "Loaded market metadata for: 'Devnet Spot INJ/USDT'"
        expected_log_record = ("pyinjective.composer.Composer", logging.INFO, expected_log_message_prefix)
        assert(expected_log_record in caplog.record_tuples)

    def test_binary_order_creation_logs_market_data_loaded_info(self, caplog, inj_usdt_market_id):
        caplog.set_level(logging.INFO)

        composer = Composer(network=Network.devnet().string())

        composer.BinaryOptionsOrder(
            market_id=inj_usdt_market_id,
            subaccount_id="",
            fee_recipient="",
            price=1.0,
            quantity=1.0,
        )

        expected_log_message_prefix = "Loaded market metadata for: 'Devnet Spot INJ/USDT'"
        expected_log_record = ("pyinjective.composer.Composer", logging.INFO, expected_log_message_prefix)
        assert(expected_log_record in caplog.record_tuples)

    def test_msg_send_logs_market_data_loaded_info(self, caplog):
        caplog.set_level(logging.INFO)

        composer = Composer(network=Network.devnet().string())

        composer.MsgSend(
            from_address="",
            to_address="",
            amount=1.0,
            denom="INJ",
        )

        expected_log_message_prefix = f"Loaded send symbol INJ (inj) with decimals = 18"
        expected_log_record = ("pyinjective.composer.Composer", logging.INFO, expected_log_message_prefix)
        assert(expected_log_record in caplog.record_tuples)

    def test_msg_deposit_logs_market_data_loaded_info(self, caplog):
        caplog.set_level(logging.INFO)

        composer = Composer(network=Network.devnet().string())

        composer.MsgDeposit(
            sender="",
            subaccount_id="",
            amount=1.0,
            denom="INJ",
        )

        expected_log_message_prefix = f"Loaded deposit symbol INJ (inj) with decimals = 18"
        expected_log_record = ("pyinjective.composer.Composer", logging.INFO, expected_log_message_prefix)
        assert(expected_log_record in caplog.record_tuples)

    def test_msg_withdraw_logs_market_data_loaded_info(self, caplog):
        caplog.set_level(logging.INFO)

        composer = Composer(network=Network.devnet().string())

        composer.MsgWithdraw(
            sender="",
            subaccount_id="",
            amount=1.0,
            denom="INJ",
        )

        expected_log_message_prefix = f"Loaded withdrawal symbol INJ (inj) with decimals = 18"
        expected_log_record = ("pyinjective.composer.Composer", logging.INFO, expected_log_message_prefix)
        assert(expected_log_record in caplog.record_tuples)

    def test_msg_external_transfer_logs_market_data_loaded_info(self, caplog):
        caplog.set_level(logging.INFO)

        composer = Composer(network=Network.devnet().string())

        composer.MsgExternalTransfer(
            sender="",
            source_subaccount_id="",
            destination_subaccount_id="",
            amount=1.0,
            denom="INJ",
        )

        expected_log_message_prefix = f"Loaded send symbol INJ (inj) with decimals = 18"
        expected_log_record = ("pyinjective.composer.Composer", logging.INFO, expected_log_message_prefix)
        assert(expected_log_record in caplog.record_tuples)

    def test_msg_send_to_eth_logs_market_data_loaded_info(self, caplog):
        caplog.set_level(logging.INFO)

        composer = Composer(network=Network.devnet().string())

        composer.MsgSendToEth(
            denom="INJ",
            sender="",
            eth_dest="",
            amount=1.0,
            bridge_fee=1.0,
        )

        expected_log_message_prefix = f"Loaded withdrawal symbol INJ (inj) with decimals = 18"
        expected_log_record = ("pyinjective.composer.Composer", logging.INFO, expected_log_message_prefix)
        assert(expected_log_record in caplog.record_tuples)

    def test_msg_create_insurance_fund_logs_market_data_loaded_info(self, caplog):
        caplog.set_level(logging.INFO)

        composer = Composer(network=Network.devnet().string())

        composer.MsgCreateInsuranceFund(
            sender="",
            ticker="",
            quote_denom="INJ",
            oracle_base="",
            oracle_quote="",
            oracle_type=1,
            expiry=1,
            initial_deposit=1,
        )

        expected_log_message_prefix = f"Loaded send symbol INJ (inj) with decimals = 18"
        expected_log_record = ("pyinjective.composer.Composer", logging.INFO, expected_log_message_prefix)
        assert(expected_log_record in caplog.record_tuples)

    def test_msg_underwrite_logs_market_data_loaded_info(self, caplog, inj_usdt_market_id):
        caplog.set_level(logging.INFO)

        composer = Composer(network=Network.devnet().string())

        composer.MsgUnderwrite(
            sender="",
            market_id=inj_usdt_market_id,
            quote_denom="INJ",
            amount=1,
        )

        expected_log_message_prefix = f"Loaded send symbol INJ (inj) with decimals = 18"
        expected_log_record = ("pyinjective.composer.Composer", logging.INFO, expected_log_message_prefix)
        assert(expected_log_record in caplog.record_tuples)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/core/connection/v1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from ibc.core.client.v1 import client_pb2 as ibc_dot_core_dot_client_dot_v1_dot_client__pb2
from ibc.core.connection.v1 import connection_pb2 as ibc_dot_core_dot_connection_dot_v1_dot_connection__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fibc/core/connection/v1/tx.proto\x12\x16ibc.core.connection.v1\x1a\x14gogoproto/gogo.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x19google/protobuf/any.proto\x1a\x1fibc/core/client/v1/client.proto\x1a\'ibc/core/connection/v1/connection.proto\"\xd9\x01\n\x15MsgConnectionOpenInit\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12@\n\x0c\x63ounterparty\x18\x02 \x01(\x0b\x32$.ibc.core.connection.v1.CounterpartyB\x04\xc8\xde\x1f\x00\x12\x30\n\x07version\x18\x03 \x01(\x0b\x32\x1f.ibc.core.connection.v1.Version\x12\x14\n\x0c\x64\x65lay_period\x18\x04 \x01(\x04\x12\x0e\n\x06signer\x18\x05 \x01(\t:\x13\x82\xe7\xb0*\x06signer\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x1f\n\x1dMsgConnectionOpenInitResponse\"\x91\x04\n\x14MsgConnectionOpenTry\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12\"\n\x16previous_connection_id\x18\x02 \x01(\tB\x02\x18\x01\x12*\n\x0c\x63lient_state\x18\x03 \x01(\x0b\x32\x14.google.protobuf.Any\x12@\n\x0c\x63ounterparty\x18\x04 \x01(\x0b\x32$.ibc.core.connection.v1.CounterpartyB\x04\xc8\xde\x1f\x00\x12\x14\n\x0c\x64\x65lay_period\x18\x05 \x01(\x04\x12>\n\x15\x63ounterparty_versions\x18\x06 \x03(\x0b\x32\x1f.ibc.core.connection.v1.Version\x12\x36\n\x0cproof_height\x18\x07 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00\x12\x12\n\nproof_init\x18\x08 \x01(\x0c\x12\x14\n\x0cproof_client\x18\t \x01(\x0c\x12\x17\n\x0fproof_consensus\x18\n \x01(\x0c\x12:\n\x10\x63onsensus_height\x18\x0b \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00\x12\x0e\n\x06signer\x18\x0c \x01(\t\x12\"\n\x1ahost_consensus_state_proof\x18\r \x01(\x0c:\x13\x82\xe7\xb0*\x06signer\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x1e\n\x1cMsgConnectionOpenTryResponse\"\xae\x03\n\x14MsgConnectionOpenAck\x12\x15\n\rconnection_id\x18\x01 \x01(\t\x12\"\n\x1a\x63ounterparty_connection_id\x18\x02 \x01(\t\x12\x30\n\x07version\x18\x03 \x01(\x0b\x32\x1f.ibc.core.connection.v1.Version\x12*\n\x0c\x63lient_state\x18\x04 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x36\n\x0cproof_height\x18\x05 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00\x12\x11\n\tproof_try\x18\x06 \x01(\x0c\x12\x14\n\x0cproof_client\x18\x07 \x01(\x0c\x12\x17\n\x0fproof_consensus\x18\x08 \x01(\x0c\x12:\n\x10\x63onsensus_height\x18\t \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00\x12\x0e\n\x06signer\x18\n \x01(\t\x12\"\n\x1ahost_consensus_state_proof\x18\x0b \x01(\x0c:\x13\x82\xe7\xb0*\x06signer\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x1e\n\x1cMsgConnectionOpenAckResponse\"\xa1\x01\n\x18MsgConnectionOpenConfirm\x12\x15\n\rconnection_id\x18\x01 \x01(\t\x12\x11\n\tproof_ack\x18\x02 \x01(\x0c\x12\x36\n\x0cproof_height\x18\x03 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00\x12\x0e\n\x06signer\x18\x04 \x01(\t:\x13\x82\xe7\xb0*\x06signer\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\"\n MsgConnectionOpenConfirmResponse\"j\n\x0fMsgUpdateParams\x12\x11\n\tauthority\x18\x01 \x01(\t\x12\x34\n\x06params\x18\x02 \x01(\x0b\x32\x1e.ibc.core.connection.v1.ParamsB\x04\xc8\xde\x1f\x00:\x0e\x82\xe7\xb0*\tauthority\"\x19\n\x17MsgUpdateParamsResponse2\xf4\x04\n\x03Msg\x12z\n\x12\x43onnectionOpenInit\x12-.ibc.core.connection.v1.MsgConnectionOpenInit\x1a\x35.ibc.core.connection.v1.MsgConnectionOpenInitResponse\x12w\n\x11\x43onnectionOpenTry\x12,.ibc.core.connection.v1.MsgConnectionOpenTry\x1a\x34.ibc.core.connection.v1.MsgConnectionOpenTryResponse\x12w\n\x11\x43onnectionOpenAck\x12,.ibc.core.connection.v1.MsgConnectionOpenAck\x1a\x34.ibc.core.connection.v1.MsgConnectionOpenAckResponse\x12\x83\x01\n\x15\x43onnectionOpenConfirm\x12\x30.ibc.core.connection.v1.MsgConnectionOpenConfirm\x1a\x38.ibc.core.connection.v1.MsgConnectionOpenConfirmResponse\x12r\n\x16UpdateConnectionParams\x12\'.ibc.core.connection.v1.MsgUpdateParams\x1a/.ibc.core.connection.v1.MsgUpdateParamsResponse\x1a\x05\x80\xe7\xb0*\x01\x42>Z<github.com/cosmos/ibc-go/v7/modules/core/03-connection/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.core.connection.v1.tx_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z<github.com/cosmos/ibc-go/v7/modules/core/03-connection/types'
  _MSGCONNECTIONOPENINIT.fields_by_name['counterparty']._options = None
  _MSGCONNECTIONOPENINIT.fields_by_name['counterparty']._serialized_options = b'\310\336\037\000'
  _MSGCONNECTIONOPENINIT._options = None
  _MSGCONNECTIONOPENINIT._serialized_options = b'\202\347\260*\006signer\350\240\037\000\210\240\037\000'
  _MSGCONNECTIONOPENTRY.fields_by_name['previous_connection_id']._options = None
  _MSGCONNECTIONOPENTRY.fields_by_name['previous_connection_id']._serialized_options = b'\030\001'
  _MSGCONNECTIONOPENTRY.fields_by_name['counterparty']._options = None
  _MSGCONNECTIONOPENTRY.fields_by_name['counterparty']._serialized_options = b'\310\336\037\000'
  _MSGCONNECTIONOPENTRY.fields_by_name['proof_height']._options = None
  _MSGCONNECTIONOPENTRY.fields_by_name['proof_height']._serialized_options = b'\310\336\037\000'
  _MSGCONNECTIONOPENTRY.fields_by_name['consensus_height']._options = None
  _MSGCONNECTIONOPENTRY.fields_by_name['consensus_height']._serialized_options = b'\310\336\037\000'
  _MSGCONNECTIONOPENTRY._options = None
  _MSGCONNECTIONOPENTRY._serialized_options = b'\202\347\260*\006signer\350\240\037\000\210\240\037\000'
  _MSGCONNECTIONOPENACK.fields_by_name['proof_height']._options = None
  _MSGCONNECTIONOPENACK.fields_by_name['proof_height']._serialized_options = b'\310\336\037\000'
  _MSGCONNECTIONOPENACK.fields_by_name['consensus_height']._options = None
  _MSGCONNECTIONOPENACK.fields_by_name['consensus_height']._serialized_options = b'\310\336\037\000'
  _MSGCONNECTIONOPENACK._options = None
  _MSGCONNECTIONOPENACK._serialized_options = b'\202\347\260*\006signer\350\240\037\000\210\240\037\000'
  _MSGCONNECTIONOPENCONFIRM.fields_by_name['proof_height']._options = None
  _MSGCONNECTIONOPENCONFIRM.fields_by_name['proof_height']._serialized_options = b'\310\336\037\000'
  _MSGCONNECTIONOPENCONFIRM._options = None
  _MSGCONNECTIONOPENCONFIRM._serialized_options = b'\202\347\260*\006signer\350\240\037\000\210\240\037\000'
  _MSGUPDATEPARAMS.fields_by_name['params']._options = None
  _MSGUPDATEPARAMS.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _MSGUPDATEPARAMS._options = None
  _MSGUPDATEPARAMS._serialized_options = b'\202\347\260*\tauthority'
  _MSG._options = None
  _MSG._serialized_options = b'\200\347\260*\001'
  _MSGCONNECTIONOPENINIT._serialized_start=208
  _MSGCONNECTIONOPENINIT._serialized_end=425
  _MSGCONNECTIONOPENINITRESPONSE._serialized_start=427
  _MSGCONNECTIONOPENINITRESPONSE._serialized_end=458
  _MSGCONNECTIONOPENTRY._serialized_start=461
  _MSGCONNECTIONOPENTRY._serialized_end=990
  _MSGCONNECTIONOPENTRYRESPONSE._serialized_start=992
  _MSGCONNECTIONOPENTRYRESPONSE._serialized_end=1022
  _MSGCONNECTIONOPENACK._serialized_start=1025
  _MSGCONNECTIONOPENACK._serialized_end=1455
  _MSGCONNECTIONOPENACKRESPONSE._serialized_start=1457
  _MSGCONNECTIONOPENACKRESPONSE._serialized_end=1487
  _MSGCONNECTIONOPENCONFIRM._serialized_start=1490
  _MSGCONNECTIONOPENCONFIRM._serialized_end=1651
  _MSGCONNECTIONOPENCONFIRMRESPONSE._serialized_start=1653
  _MSGCONNECTIONOPENCONFIRMRESPONSE._serialized_end=1687
  _MSGUPDATEPARAMS._serialized_start=1689
  _MSGUPDATEPARAMS._serialized_end=1795
  _MSGUPDATEPARAMSRESPONSE._serialized_start=1797
  _MSGUPDATEPARAMSRESPONSE._serialized_end=1822
  _MSG._serialized_start=1825
  _MSG._serialized_end=2453
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/lightclients/tendermint/v1/tendermint.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from tendermint.types import validator_pb2 as tendermint_dot_types_dot_validator__pb2
from tendermint.types import types_pb2 as tendermint_dot_types_dot_types__pb2
from cosmos.ics23.v1 import proofs_pb2 as cosmos_dot_ics23_dot_v1_dot_proofs__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from ibc.core.client.v1 import client_pb2 as ibc_dot_core_dot_client_dot_v1_dot_client__pb2
from ibc.core.commitment.v1 import commitment_pb2 as ibc_dot_core_dot_commitment_dot_v1_dot_commitment__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/ibc/lightclients/tendermint/v1/tendermint.proto\x12\x1eibc.lightclients.tendermint.v1\x1a tendermint/types/validator.proto\x1a\x1ctendermint/types/types.proto\x1a\x1c\x63osmos/ics23/v1/proofs.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1fibc/core/client/v1/client.proto\x1a\'ibc/core/commitment/v1/commitment.proto\x1a\x14gogoproto/gogo.proto\"\xb2\x04\n\x0b\x43lientState\x12\x10\n\x08\x63hain_id\x18\x01 \x01(\t\x12\x43\n\x0btrust_level\x18\x02 \x01(\x0b\x32(.ibc.lightclients.tendermint.v1.FractionB\x04\xc8\xde\x1f\x00\x12<\n\x0ftrusting_period\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xc8\xde\x1f\x00\x98\xdf\x1f\x01\x12=\n\x10unbonding_period\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xc8\xde\x1f\x00\x98\xdf\x1f\x01\x12<\n\x0fmax_clock_drift\x18\x05 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xc8\xde\x1f\x00\x98\xdf\x1f\x01\x12\x37\n\rfrozen_height\x18\x06 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00\x12\x37\n\rlatest_height\x18\x07 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00\x12/\n\x0bproof_specs\x18\x08 \x03(\x0b\x32\x1a.cosmos.ics23.v1.ProofSpec\x12\x14\n\x0cupgrade_path\x18\t \x03(\t\x12%\n\x19\x61llow_update_after_expiry\x18\n \x01(\x08\x42\x02\x18\x01\x12+\n\x1f\x61llow_update_after_misbehaviour\x18\x0b \x01(\x08\x42\x02\x18\x01:\x04\x88\xa0\x1f\x00\"\xdb\x01\n\x0e\x43onsensusState\x12\x37\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x12\x36\n\x04root\x18\x02 \x01(\x0b\x32\".ibc.core.commitment.v1.MerkleRootB\x04\xc8\xde\x1f\x00\x12R\n\x14next_validators_hash\x18\x03 \x01(\x0c\x42\x34\xfa\xde\x1f\x30github.com/cometbft/cometbft/libs/bytes.HexBytes:\x04\x88\xa0\x1f\x00\"\xb9\x01\n\x0cMisbehaviour\x12\x15\n\tclient_id\x18\x01 \x01(\tB\x02\x18\x01\x12\x45\n\x08header_1\x18\x02 \x01(\x0b\x32&.ibc.lightclients.tendermint.v1.HeaderB\x0b\xe2\xde\x1f\x07Header1\x12\x45\n\x08header_2\x18\x03 \x01(\x0b\x32&.ibc.lightclients.tendermint.v1.HeaderB\x0b\xe2\xde\x1f\x07Header2:\x04\x88\xa0\x1f\x00\"\xf2\x01\n\x06Header\x12;\n\rsigned_header\x18\x01 \x01(\x0b\x32\x1e.tendermint.types.SignedHeaderB\x04\xd0\xde\x1f\x01\x12\x35\n\rvalidator_set\x18\x02 \x01(\x0b\x32\x1e.tendermint.types.ValidatorSet\x12\x38\n\x0etrusted_height\x18\x03 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00\x12:\n\x12trusted_validators\x18\x04 \x01(\x0b\x32\x1e.tendermint.types.ValidatorSet\"2\n\x08\x46raction\x12\x11\n\tnumerator\x18\x01 \x01(\x04\x12\x13\n\x0b\x64\x65nominator\x18\x02 \x01(\x04\x42LZJgithub.com/cosmos/ibc-go/v7/modules/light-clients/07-tendermint;tendermintb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.lightclients.tendermint.v1.tendermint_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZJgithub.com/cosmos/ibc-go/v7/modules/light-clients/07-tendermint;tendermint'
  _CLIENTSTATE.fields_by_name['trust_level']._options = None
  _CLIENTSTATE.fields_by_name['trust_level']._serialized_options = b'\310\336\037\000'
  _CLIENTSTATE.fields_by_name['trusting_period']._options = None
  _CLIENTSTATE.fields_by_name['trusting_period']._serialized_options = b'\310\336\037\000\230\337\037\001'
  _CLIENTSTATE.fields_by_name['unbonding_period']._options = None
  _CLIENTSTATE.fields_by_name['unbonding_period']._serialized_options = b'\310\336\037\000\230\337\037\001'
  _CLIENTSTATE.fields_by_name['max_clock_drift']._options = None
  _CLIENTSTATE.fields_by_name['max_clock_drift']._serialized_options = b'\310\336\037\000\230\337\037\001'
  _CLIENTSTATE.fields_by_name['frozen_height']._options = None
  _CLIENTSTATE.fields_by_name['frozen_height']._serialized_options = b'\310\336\037\000'
  _CLIENTSTATE.fields_by_name['latest_height']._options = None
  _CLIENTSTATE.fields_by_name['latest_height']._serialized_options = b'\310\336\037\000'
  _CLIENTSTATE.fields_by_name['allow_update_after_expiry']._options = None
  _CLIENTSTATE.fields_by_name['allow_update_after_expiry']._serialized_options = b'\030\001'
  _CLIENTSTATE.fields_by_name['allow_update_after_misbehaviour']._options = None
  _CLIENTSTATE.fields_by_name['allow_update_after_misbehaviour']._serialized_options = b'\030\001'
  _CLIENTSTATE._options = None
  _CLIENTSTATE._serialized_options = b'\210\240\037\000'
  _CONSENSUSSTATE.fields_by_name['timestamp']._options = None
  _CONSENSUSSTATE.fields_by_name['timestamp']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _CONSENSUSSTATE.fields_by_name['root']._options = None
  _CONSENSUSSTATE.fields_by_name['root']._serialized_options = b'\310\336\037\000'
  _CONSENSUSSTATE.fields_by_name['next_validators_hash']._options = None
  _CONSENSUSSTATE.fields_by_name['next_validators_hash']._serialized_options = b'\372\336\0370github.com/cometbft/cometbft/libs/bytes.HexBytes'
  _CONSENSUSSTATE._options = None
  _CONSENSUSSTATE._serialized_options = b'\210\240\037\000'
  _MISBEHAVIOUR.fields_by_name['client_id']._options = None
  _MISBEHAVIOUR.fields_by_name['client_id']._serialized_options = b'\030\001'
  _MISBEHAVIOUR.fields_by_name['header_1']._options = None
  _MISBEHAVIOUR.fields_by_name['header_1']._serialized_options = b'\342\336\037\007Header1'
  _MISBEHAVIOUR.fields_by_name['header_2']._options = None
  _MISBEHAVIOUR.fields_by_name['header_2']._serialized_options = b'\342\336\037\007Header2'
  _MISBEHAVIOUR._options = None
  _MISBEHAVIOUR._serialized_options = b'\210\240\037\000'
  _HEADER.fields_by_name['signed_header']._options = None
  _HEADER.fields_by_name['signed_header']._serialized_options = b'\320\336\037\001'
  _HEADER.fields_by_name['trusted_height']._options = None
  _HEADER.fields_by_name['trusted_height']._serialized_options = b'\310\336\037\000'
  _CLIENTSTATE._serialized_start=339
  _CLIENTSTATE._serialized_end=901
  _CONSENSUSSTATE._serialized_start=904
  _CONSENSUSSTATE._serialized_end=1123
  _MISBEHAVIOUR._serialized_start=1126
  _MISBEHAVIOUR._serialized_end=1311
  _HEADER._serialized_start=1314
  _HEADER._serialized_end=1556
  _FRACTION._serialized_start=1558
  _FRACTION._serialized_end=1608
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/bank/v1beta1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from cosmos.bank.v1beta1 import bank_pb2 as cosmos_dot_bank_dot_v1beta1_dot_bank__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x63osmos/bank/v1beta1/tx.proto\x12\x13\x63osmos.bank.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x1e\x63osmos/bank/v1beta1/bank.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x11\x61mino/amino.proto\"\xfb\x01\n\x07MsgSend\x12.\n\x0c\x66rom_address\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12,\n\nto_address\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12`\n\x06\x61mount\x18\x03 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB5\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins:0\x82\xe7\xb0*\x0c\x66rom_address\x8a\xe7\xb0*\x12\x63osmos-sdk/MsgSend\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x11\n\x0fMsgSendResponse\"\xab\x01\n\x0cMsgMultiSend\x12\x35\n\x06inputs\x18\x01 \x03(\x0b\x32\x1a.cosmos.bank.v1beta1.InputB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12\x37\n\x07outputs\x18\x02 \x03(\x0b\x32\x1b.cosmos.bank.v1beta1.OutputB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01:+\x82\xe7\xb0*\x06inputs\x8a\xe7\xb0*\x17\x63osmos-sdk/MsgMultiSend\xe8\xa0\x1f\x00\"\x16\n\x14MsgMultiSendResponse\"\xac\x01\n\x0fMsgUpdateParams\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x36\n\x06params\x18\x02 \x01(\x0b\x32\x1b.cosmos.bank.v1beta1.ParamsB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01:4\x82\xe7\xb0*\tauthority\x8a\xe7\xb0*!cosmos-sdk/x/bank/MsgUpdateParams\"\x19\n\x17MsgUpdateParamsResponse\"\xc2\x01\n\x11MsgSetSendEnabled\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x36\n\x0csend_enabled\x18\x02 \x03(\x0b\x32 .cosmos.bank.v1beta1.SendEnabled\x12\x17\n\x0fuse_default_for\x18\x03 \x03(\t:/\x82\xe7\xb0*\tauthority\x8a\xe7\xb0*\x1c\x63osmos-sdk/MsgSetSendEnabled\"\x1b\n\x19MsgSetSendEnabledResponse2\x81\x03\n\x03Msg\x12J\n\x04Send\x12\x1c.cosmos.bank.v1beta1.MsgSend\x1a$.cosmos.bank.v1beta1.MsgSendResponse\x12Y\n\tMultiSend\x12!.cosmos.bank.v1beta1.MsgMultiSend\x1a).cosmos.bank.v1beta1.MsgMultiSendResponse\x12\x62\n\x0cUpdateParams\x12$.cosmos.bank.v1beta1.MsgUpdateParams\x1a,.cosmos.bank.v1beta1.MsgUpdateParamsResponse\x12h\n\x0eSetSendEnabled\x12&.cosmos.bank.v1beta1.MsgSetSendEnabled\x1a..cosmos.bank.v1beta1.MsgSetSendEnabledResponse\x1a\x05\x80\xe7\xb0*\x01\x42+Z)github.com/cosmos/cosmos-sdk/x/bank/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.bank.v1beta1.tx_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z)github.com/cosmos/cosmos-sdk/x/bank/types'
  _MSGSEND.fields_by_name['from_address']._options = None
  _MSGSEND.fields_by_name['from_address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _MSGSEND.fields_by_name['to_address']._options = None
  _MSGSEND.fields_by_name['to_address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _MSGSEND.fields_by_name['amount']._options = None
  _MSGSEND.fields_by_name['amount']._serialized_options = b'\310\336\037\000\250\347\260*\001\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _MSGSEND._options = None
  _MSGSEND._serialized_options = b'\202\347\260*\014from_address\212\347\260*\022cosmos-sdk/MsgSend\350\240\037\000\210\240\037\000'
  _MSGMULTISEND.fields_by_name['inputs']._options = None
  _MSGMULTISEND.fields_by_name['inputs']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _MSGMULTISEND.fields_by_name['outputs']._options = None
  _MSGMULTISEND.fields_by_name['outputs']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _MSGMULTISEND._options = None
  _MSGMULTISEND._serialized_options = b'\202\347\260*\006inputs\212\347\260*\027cosmos-sdk/MsgMultiSend\350\240\037\000'
  _MSGUPDATEPARAMS.fields_by_name['authority']._options = None
  _MSGUPDATEPARAMS.fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _MSGUPDATEPARAMS.fields_by_name['params']._options = None
  _MSGUPDATEPARAMS.fields_by_name['params']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _MSGUPDATEPARAMS._options = None
  _MSGUPDATEPARAMS._serialized_options = b'\202\347\260*\tauthority\212\347\260*!cosmos-sdk/x/bank/MsgUpdateParams'
  _MSGSETSENDENABLED.fields_by_name['authority']._options = None
  _MSGSETSENDENABLED.fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _MSGSETSENDENABLED._options = None
  _MSGSETSENDENABLED._serialized_options = b'\202\347\260*\tauthority\212\347\260*\034cosmos-sdk/MsgSetSendEnabled'
  _MSG._options = None
  _MSG._serialized_options = b'\200\347\260*\001'
  _MSGSEND._serialized_start=211
  _MSGSEND._serialized_end=462
  _MSGSENDRESPONSE._serialized_start=464
  _MSGSENDRESPONSE._serialized_end=481
  _MSGMULTISEND._serialized_start=484
  _MSGMULTISEND._serialized_end=655
  _MSGMULTISENDRESPONSE._serialized_start=657
  _MSGMULTISENDRESPONSE._serialized_end=679
  _MSGUPDATEPARAMS._serialized_start=682
  _MSGUPDATEPARAMS._serialized_end=854
  _MSGUPDATEPARAMSRESPONSE._serialized_start=856
  _MSGUPDATEPARAMSRESPONSE._serialized_end=881
  _MSGSETSENDENABLED._serialized_start=884
  _MSGSETSENDENABLED._serialized_end=1078
  _MSGSETSENDENABLEDRESPONSE._serialized_start=1080
  _MSGSETSENDENABLEDRESPONSE._serialized_end=1107
  _MSG._serialized_start=1110
  _MSG._serialized_end=1495
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/wasmx/v1/events.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from injective.wasmx.v1 import wasmx_pb2 as injective_dot_wasmx_dot_v1_dot_wasmx__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1finjective/wasmx/v1/events.proto\x12\x12injective.wasmx.v1\x1a\x1einjective/wasmx/v1/wasmx.proto\x1a\x14gogoproto/gogo.proto\"S\n\x16\x45ventContractExecution\x12\x18\n\x10\x63ontract_address\x18\x01 \x01(\t\x12\x10\n\x08response\x18\x02 \x01(\x0c\x12\r\n\x05\x65rror\x18\x03 \x01(\tBMZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/wasmx/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.wasmx.v1.events_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/wasmx/types'
  _EVENTCONTRACTEXECUTION._serialized_start=109
  _EVENTCONTRACTEXECUTION._serialized_end=192
# @@protoc_insertion_point(module_scope)



import os
from configparser import ConfigParser

MAX_CLIENT_ID_LENGTH = 128
MAX_DATA_SIZE = 256
MAX_MEMO_CHARACTERS = 256

devnet_config = ConfigParser()
devnet_config.read(os.path.join(os.path.dirname(__file__), "denoms_devnet.ini"))

testnet_config = ConfigParser()
testnet_config.read(os.path.join(os.path.dirname(__file__), "denoms_testnet.ini"))

mainnet_config = ConfigParser()
mainnet_config.read(os.path.join(os.path.dirname(__file__), "denoms_mainnet.ini"))

class Denom:
    def __init__(
        self,
        description: str,
        base: int,
        quote: int,
        min_price_tick_size: float,
        min_quantity_tick_size: float
    ):
        self.description = description
        self.base = base
        self.quote = quote
        self.min_price_tick_size = min_price_tick_size
        self.min_quantity_tick_size = min_quantity_tick_size

    @classmethod
    def load_market(cls, network, market_id):
        if network == "devnet":
            config = devnet_config
        elif network == "testnet":
            config = testnet_config
        else:
            config =mainnet_config

        return cls(
            description=config[market_id]["description"],
            base=int(config[market_id]["base"]),
            quote=int(config[market_id]["quote"]),
            min_price_tick_size=float(config[market_id]["min_price_tick_size"]),
            min_quantity_tick_size=float(config[market_id]["min_quantity_tick_size"]),
        )

    @classmethod
    def load_peggy_denom(cls, network, symbol):
        if network == "devnet":
            config = devnet_config
        elif network == "local":
            config = devnet_config
        elif network == "testnet":
            config = testnet_config
        else:
            config = mainnet_config
        return config[symbol]["peggy_denom"], int(config[symbol]["decimals"])


class Network:
    def __init__(
        self,
        lcd_endpoint: str ,
        tm_websocket_endpoint: str,
        grpc_endpoint: str ,
        grpc_exchange_endpoint: str ,
        grpc_explorer_endpoint: str ,
        chain_id: str ,
        fee_denom: str ,
        env: str
    ):
        self.lcd_endpoint = lcd_endpoint
        self.tm_websocket_endpoint = tm_websocket_endpoint
        self.grpc_endpoint = grpc_endpoint
        self.grpc_exchange_endpoint = grpc_exchange_endpoint
        self.grpc_explorer_endpoint = grpc_explorer_endpoint
        self.chain_id = chain_id
        self.fee_denom = fee_denom
        self.env = env

    @classmethod
    def devnet(cls):
        return cls(
            lcd_endpoint="https://devnet.lcd.injective.dev",
            tm_websocket_endpoint="wss://devnet.tm.injective.dev/websocket",
            grpc_endpoint="devnet.injective.dev:9900",
            grpc_exchange_endpoint="devnet.injective.dev:9910",
            grpc_explorer_endpoint="devnet.injective.dev:9911",
            chain_id="injective-777",
            fee_denom="inj",
            env="devnet"
        )

    @classmethod
    def testnet(cls, node="lb"):
        nodes = [
            "lb",
            "sentry",
        ]
        if node not in nodes:
            raise ValueError("Must be one of {}".format(nodes))

        if node == "lb":
            lcd_endpoint = "https://k8s.testnet.lcd.injective.network"
            tm_websocket_endpoint = "wss://k8s.testnet.tm.injective.network/websocket"
            grpc_endpoint = "k8s.testnet.chain.grpc.injective.network:443"
            grpc_exchange_endpoint = "k8s.testnet.exchange.grpc.injective.network:443"
            grpc_explorer_endpoint = "k8s.testnet.explorer.grpc.injective.network:443"
        else:
            lcd_endpoint = "https://testnet.lcd.injective.network"
            tm_websocket_endpoint = "wss://testnet.tm.injective.network/websocket"
            grpc_endpoint = "testnet.chain.grpc.injective.network"
            grpc_exchange_endpoint = "testnet.exchange.grpc.injective.network"
            grpc_explorer_endpoint = "testnet.explorer.grpc.injective.network"

        return cls(
            lcd_endpoint=lcd_endpoint,
            tm_websocket_endpoint=tm_websocket_endpoint,
            grpc_endpoint=grpc_endpoint,
            grpc_exchange_endpoint=grpc_exchange_endpoint,
            grpc_explorer_endpoint=grpc_explorer_endpoint,
            chain_id="injective-888",
            fee_denom="inj",
            env="testnet"
        )

    @classmethod
    def mainnet(cls, node="lb"):
        nodes = [
            "lb", # us, asia, prod
            "sentry0",  # ca, prod
            "sentry1",  # ca, prod
            "sentry3",  # us, prod
        ]
        if node not in nodes:
            raise ValueError("Must be one of {}".format(nodes))

        if node == "lb":
            lcd_endpoint = "https://k8s.global.mainnet.lcd.injective.network:443"
            tm_websocket_endpoint = "wss://k8s.global.mainnet.tm.injective.network:443/websocket"
            grpc_endpoint = "k8s.global.mainnet.chain.grpc.injective.network:443"
            grpc_exchange_endpoint = "k8s.global.mainnet.exchange.grpc.injective.network:443"
            grpc_explorer_endpoint = "k8s.global.mainnet.explorer.grpc.injective.network:443"
        else:
            lcd_endpoint = f"http://{node}.injective.network:10337"
            tm_websocket_endpoint = f"ws://{node}.injective.network:26657/websocket"
            grpc_endpoint = f"{node}.injective.network:9900"
            grpc_exchange_endpoint = f"{node}.injective.network:9910"
            grpc_explorer_endpoint = f"{node}.injective.network:9911"

        return cls(
            lcd_endpoint=lcd_endpoint,
            tm_websocket_endpoint=tm_websocket_endpoint,
            grpc_endpoint=grpc_endpoint,
            grpc_exchange_endpoint=grpc_exchange_endpoint,
            grpc_explorer_endpoint=grpc_explorer_endpoint,
            chain_id="injective-1",
            fee_denom="inj",
            env="mainnet"
        )

    @classmethod
    def local(cls):
        return cls(
            lcd_endpoint="http://localhost:10337",
            tm_websocket_endpoint="ws://localhost:26657/websocket",
            grpc_endpoint="localhost:9900",
            grpc_exchange_endpoint="localhost:9910",
            grpc_explorer_endpoint="localhost:9911",
            chain_id="injective-1",
            fee_denom="inj",
            env="local"
        )

    @classmethod
    def custom(cls, lcd_endpoint, tm_websocket_endpoint, grpc_endpoint, grpc_exchange_endpoint, grpc_explorer_endpoint, chain_id, env):
        return cls(
            lcd_endpoint=lcd_endpoint,
            tm_websocket_endpoint=tm_websocket_endpoint,
            grpc_endpoint=grpc_endpoint,
            grpc_exchange_endpoint=grpc_exchange_endpoint,
            grpc_explorer_endpoint=grpc_explorer_endpoint,
            chain_id=chain_id,
            fee_denom="inj",
            env=env
        )

    def string(self):
        return self.env



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/tokenfactory/v1beta1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from cosmos.bank.v1beta1 import bank_pb2 as cosmos_dot_bank_dot_v1beta1_dot_bank__pb2
from cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from injective.tokenfactory.v1beta1 import params_pb2 as injective_dot_tokenfactory_dot_v1beta1_dot_params__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'injective/tokenfactory/v1beta1/tx.proto\x12\x1einjective.tokenfactory.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x1e\x63osmos/bank/v1beta1/bank.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a+injective/tokenfactory/v1beta1/params.proto\"g\n\x0eMsgCreateDenom\x12!\n\x06sender\x18\x01 \x01(\tB\x11\xf2\xde\x1f\ryaml:\"sender\"\x12%\n\x08subdenom\x18\x02 \x01(\tB\x13\xf2\xde\x1f\x0fyaml:\"subdenom\":\x0b\x82\xe7\xb0*\x06sender\"M\n\x16MsgCreateDenomResponse\x12\x33\n\x0fnew_token_denom\x18\x01 \x01(\tB\x1a\xf2\xde\x1f\x16yaml:\"new_token_denom\"\"{\n\x07MsgMint\x12!\n\x06sender\x18\x01 \x01(\tB\x11\xf2\xde\x1f\ryaml:\"sender\"\x12@\n\x06\x61mount\x18\x02 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x15\xf2\xde\x1f\ryaml:\"amount\"\xc8\xde\x1f\x00:\x0b\x82\xe7\xb0*\x06sender\"\x11\n\x0fMsgMintResponse\"{\n\x07MsgBurn\x12!\n\x06sender\x18\x01 \x01(\tB\x11\xf2\xde\x1f\ryaml:\"sender\"\x12@\n\x06\x61mount\x18\x02 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x15\xf2\xde\x1f\ryaml:\"amount\"\xc8\xde\x1f\x00:\x0b\x82\xe7\xb0*\x06sender\"\x11\n\x0fMsgBurnResponse\"\x8a\x01\n\x0eMsgChangeAdmin\x12!\n\x06sender\x18\x01 \x01(\tB\x11\xf2\xde\x1f\ryaml:\"sender\"\x12\x1f\n\x05\x64\x65nom\x18\x02 \x01(\tB\x10\xf2\xde\x1f\x0cyaml:\"denom\"\x12\'\n\tnew_admin\x18\x03 \x01(\tB\x14\xf2\xde\x1f\x10yaml:\"new_admin\":\x0b\x82\xe7\xb0*\x06sender\"\x18\n\x16MsgChangeAdminResponse\"\x8f\x01\n\x13MsgSetDenomMetadata\x12!\n\x06sender\x18\x01 \x01(\tB\x11\xf2\xde\x1f\ryaml:\"sender\"\x12H\n\x08metadata\x18\x02 \x01(\x0b\x32\x1d.cosmos.bank.v1beta1.MetadataB\x17\xf2\xde\x1f\x0fyaml:\"metadata\"\xc8\xde\x1f\x00:\x0b\x82\xe7\xb0*\x06sender\"\x1d\n\x1bMsgSetDenomMetadataResponse\"\x8c\x01\n\x0fMsgUpdateParams\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12<\n\x06params\x18\x02 \x01(\x0b\x32&.injective.tokenfactory.v1beta1.ParamsB\x04\xc8\xde\x1f\x00:\x0e\x82\xe7\xb0*\tauthority\"\x19\n\x17MsgUpdateParamsResponse2\xb8\x05\n\x03Msg\x12u\n\x0b\x43reateDenom\x12..injective.tokenfactory.v1beta1.MsgCreateDenom\x1a\x36.injective.tokenfactory.v1beta1.MsgCreateDenomResponse\x12`\n\x04Mint\x12\'.injective.tokenfactory.v1beta1.MsgMint\x1a/.injective.tokenfactory.v1beta1.MsgMintResponse\x12`\n\x04\x42urn\x12\'.injective.tokenfactory.v1beta1.MsgBurn\x1a/.injective.tokenfactory.v1beta1.MsgBurnResponse\x12u\n\x0b\x43hangeAdmin\x12..injective.tokenfactory.v1beta1.MsgChangeAdmin\x1a\x36.injective.tokenfactory.v1beta1.MsgChangeAdminResponse\x12\x84\x01\n\x10SetDenomMetadata\x12\x33.injective.tokenfactory.v1beta1.MsgSetDenomMetadata\x1a;.injective.tokenfactory.v1beta1.MsgSetDenomMetadataResponse\x12x\n\x0cUpdateParams\x12/.injective.tokenfactory.v1beta1.MsgUpdateParams\x1a\x37.injective.tokenfactory.v1beta1.MsgUpdateParamsResponseBTZRgithub.com/InjectiveLabs/injective-core/injective-chain/modules/tokenfactory/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.tokenfactory.v1beta1.tx_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZRgithub.com/InjectiveLabs/injective-core/injective-chain/modules/tokenfactory/types'
  _MSGCREATEDENOM.fields_by_name['sender']._options = None
  _MSGCREATEDENOM.fields_by_name['sender']._serialized_options = b'\362\336\037\ryaml:\"sender\"'
  _MSGCREATEDENOM.fields_by_name['subdenom']._options = None
  _MSGCREATEDENOM.fields_by_name['subdenom']._serialized_options = b'\362\336\037\017yaml:\"subdenom\"'
  _MSGCREATEDENOM._options = None
  _MSGCREATEDENOM._serialized_options = b'\202\347\260*\006sender'
  _MSGCREATEDENOMRESPONSE.fields_by_name['new_token_denom']._options = None
  _MSGCREATEDENOMRESPONSE.fields_by_name['new_token_denom']._serialized_options = b'\362\336\037\026yaml:\"new_token_denom\"'
  _MSGMINT.fields_by_name['sender']._options = None
  _MSGMINT.fields_by_name['sender']._serialized_options = b'\362\336\037\ryaml:\"sender\"'
  _MSGMINT.fields_by_name['amount']._options = None
  _MSGMINT.fields_by_name['amount']._serialized_options = b'\362\336\037\ryaml:\"amount\"\310\336\037\000'
  _MSGMINT._options = None
  _MSGMINT._serialized_options = b'\202\347\260*\006sender'
  _MSGBURN.fields_by_name['sender']._options = None
  _MSGBURN.fields_by_name['sender']._serialized_options = b'\362\336\037\ryaml:\"sender\"'
  _MSGBURN.fields_by_name['amount']._options = None
  _MSGBURN.fields_by_name['amount']._serialized_options = b'\362\336\037\ryaml:\"amount\"\310\336\037\000'
  _MSGBURN._options = None
  _MSGBURN._serialized_options = b'\202\347\260*\006sender'
  _MSGCHANGEADMIN.fields_by_name['sender']._options = None
  _MSGCHANGEADMIN.fields_by_name['sender']._serialized_options = b'\362\336\037\ryaml:\"sender\"'
  _MSGCHANGEADMIN.fields_by_name['denom']._options = None
  _MSGCHANGEADMIN.fields_by_name['denom']._serialized_options = b'\362\336\037\014yaml:\"denom\"'
  _MSGCHANGEADMIN.fields_by_name['new_admin']._options = None
  _MSGCHANGEADMIN.fields_by_name['new_admin']._serialized_options = b'\362\336\037\020yaml:\"new_admin\"'
  _MSGCHANGEADMIN._options = None
  _MSGCHANGEADMIN._serialized_options = b'\202\347\260*\006sender'
  _MSGSETDENOMMETADATA.fields_by_name['sender']._options = None
  _MSGSETDENOMMETADATA.fields_by_name['sender']._serialized_options = b'\362\336\037\ryaml:\"sender\"'
  _MSGSETDENOMMETADATA.fields_by_name['metadata']._options = None
  _MSGSETDENOMMETADATA.fields_by_name['metadata']._serialized_options = b'\362\336\037\017yaml:\"metadata\"\310\336\037\000'
  _MSGSETDENOMMETADATA._options = None
  _MSGSETDENOMMETADATA._serialized_options = b'\202\347\260*\006sender'
  _MSGUPDATEPARAMS.fields_by_name['authority']._options = None
  _MSGUPDATEPARAMS.fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _MSGUPDATEPARAMS.fields_by_name['params']._options = None
  _MSGUPDATEPARAMS.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _MSGUPDATEPARAMS._options = None
  _MSGUPDATEPARAMS._serialized_options = b'\202\347\260*\tauthority'
  _MSGCREATEDENOM._serialized_start=258
  _MSGCREATEDENOM._serialized_end=361
  _MSGCREATEDENOMRESPONSE._serialized_start=363
  _MSGCREATEDENOMRESPONSE._serialized_end=440
  _MSGMINT._serialized_start=442
  _MSGMINT._serialized_end=565
  _MSGMINTRESPONSE._serialized_start=567
  _MSGMINTRESPONSE._serialized_end=584
  _MSGBURN._serialized_start=586
  _MSGBURN._serialized_end=709
  _MSGBURNRESPONSE._serialized_start=711
  _MSGBURNRESPONSE._serialized_end=728
  _MSGCHANGEADMIN._serialized_start=731
  _MSGCHANGEADMIN._serialized_end=869
  _MSGCHANGEADMINRESPONSE._serialized_start=871
  _MSGCHANGEADMINRESPONSE._serialized_end=895
  _MSGSETDENOMMETADATA._serialized_start=898
  _MSGSETDENOMMETADATA._serialized_end=1041
  _MSGSETDENOMMETADATARESPONSE._serialized_start=1043
  _MSGSETDENOMMETADATARESPONSE._serialized_end=1072
  _MSGUPDATEPARAMS._serialized_start=1075
  _MSGUPDATEPARAMS._serialized_end=1215
  _MSGUPDATEPARAMSRESPONSE._serialized_start=1217
  _MSGUPDATEPARAMSRESPONSE._serialized_end=1242
  _MSG._serialized_start=1245
  _MSG._serialized_end=1941
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/distribution/v1beta1/genesis.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from cosmos.distribution.v1beta1 import distribution_pb2 as cosmos_dot_distribution_dot_v1beta1_dot_distribution__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)cosmos/distribution/v1beta1/genesis.proto\x12\x1b\x63osmos.distribution.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a.cosmos/distribution/v1beta1/distribution.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x11\x61mino/amino.proto\"\x8a\x01\n\x15\x44\x65legatorWithdrawInfo\x12\x33\n\x11\x64\x65legator_address\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x32\n\x10withdraw_address\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\xd7\x01\n!ValidatorOutstandingRewardsRecord\x12\x33\n\x11validator_address\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12s\n\x13outstanding_rewards\x18\x02 \x03(\x0b\x32\x1c.cosmos.base.v1beta1.DecCoinB8\xaa\xdf\x1f+github.com/cosmos/cosmos-sdk/types.DecCoins\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\xc2\x01\n$ValidatorAccumulatedCommissionRecord\x12\x33\n\x11validator_address\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12[\n\x0b\x61\x63\x63umulated\x18\x02 \x01(\x0b\x32;.cosmos.distribution.v1beta1.ValidatorAccumulatedCommissionB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\xc6\x01\n ValidatorHistoricalRewardsRecord\x12\x33\n\x11validator_address\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x0e\n\x06period\x18\x02 \x01(\x04\x12S\n\x07rewards\x18\x03 \x01(\x0b\x32\x37.cosmos.distribution.v1beta1.ValidatorHistoricalRewardsB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\xb0\x01\n\x1dValidatorCurrentRewardsRecord\x12\x33\n\x11validator_address\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12P\n\x07rewards\x18\x02 \x01(\x0b\x32\x34.cosmos.distribution.v1beta1.ValidatorCurrentRewardsB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\xe7\x01\n\x1b\x44\x65legatorStartingInfoRecord\x12\x33\n\x11\x64\x65legator_address\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x33\n\x11validator_address\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12T\n\rstarting_info\x18\x03 \x01(\x0b\x32\x32.cosmos.distribution.v1beta1.DelegatorStartingInfoB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\xd6\x01\n\x19ValidatorSlashEventRecord\x12\x33\n\x11validator_address\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x0e\n\x06height\x18\x02 \x01(\x04\x12\x0e\n\x06period\x18\x03 \x01(\x04\x12Z\n\x15validator_slash_event\x18\x04 \x01(\x0b\x32\x30.cosmos.distribution.v1beta1.ValidatorSlashEventB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\xb6\x07\n\x0cGenesisState\x12>\n\x06params\x18\x01 \x01(\x0b\x32#.cosmos.distribution.v1beta1.ParamsB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12\x41\n\x08\x66\x65\x65_pool\x18\x02 \x01(\x0b\x32$.cosmos.distribution.v1beta1.FeePoolB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12_\n\x18\x64\x65legator_withdraw_infos\x18\x03 \x03(\x0b\x32\x32.cosmos.distribution.v1beta1.DelegatorWithdrawInfoB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12\x33\n\x11previous_proposer\x18\x04 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x66\n\x13outstanding_rewards\x18\x05 \x03(\x0b\x32>.cosmos.distribution.v1beta1.ValidatorOutstandingRewardsRecordB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12w\n!validator_accumulated_commissions\x18\x06 \x03(\x0b\x32\x41.cosmos.distribution.v1beta1.ValidatorAccumulatedCommissionRecordB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12n\n\x1cvalidator_historical_rewards\x18\x07 \x03(\x0b\x32=.cosmos.distribution.v1beta1.ValidatorHistoricalRewardsRecordB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12h\n\x19validator_current_rewards\x18\x08 \x03(\x0b\x32:.cosmos.distribution.v1beta1.ValidatorCurrentRewardsRecordB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12\x65\n\x18\x64\x65legator_starting_infos\x18\t \x03(\x0b\x32\x38.cosmos.distribution.v1beta1.DelegatorStartingInfoRecordB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12\x61\n\x16validator_slash_events\x18\n \x03(\x0b\x32\x36.cosmos.distribution.v1beta1.ValidatorSlashEventRecordB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\x42\x37Z1github.com/cosmos/cosmos-sdk/x/distribution/types\xa8\xe2\x1e\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.distribution.v1beta1.genesis_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1github.com/cosmos/cosmos-sdk/x/distribution/types\250\342\036\001'
  _DELEGATORWITHDRAWINFO.fields_by_name['delegator_address']._options = None
  _DELEGATORWITHDRAWINFO.fields_by_name['delegator_address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _DELEGATORWITHDRAWINFO.fields_by_name['withdraw_address']._options = None
  _DELEGATORWITHDRAWINFO.fields_by_name['withdraw_address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _DELEGATORWITHDRAWINFO._options = None
  _DELEGATORWITHDRAWINFO._serialized_options = b'\350\240\037\000\210\240\037\000'
  _VALIDATOROUTSTANDINGREWARDSRECORD.fields_by_name['validator_address']._options = None
  _VALIDATOROUTSTANDINGREWARDSRECORD.fields_by_name['validator_address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _VALIDATOROUTSTANDINGREWARDSRECORD.fields_by_name['outstanding_rewards']._options = None
  _VALIDATOROUTSTANDINGREWARDSRECORD.fields_by_name['outstanding_rewards']._serialized_options = b'\252\337\037+github.com/cosmos/cosmos-sdk/types.DecCoins\310\336\037\000\250\347\260*\001'
  _VALIDATOROUTSTANDINGREWARDSRECORD._options = None
  _VALIDATOROUTSTANDINGREWARDSRECORD._serialized_options = b'\350\240\037\000\210\240\037\000'
  _VALIDATORACCUMULATEDCOMMISSIONRECORD.fields_by_name['validator_address']._options = None
  _VALIDATORACCUMULATEDCOMMISSIONRECORD.fields_by_name['validator_address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _VALIDATORACCUMULATEDCOMMISSIONRECORD.fields_by_name['accumulated']._options = None
  _VALIDATORACCUMULATEDCOMMISSIONRECORD.fields_by_name['accumulated']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _VALIDATORACCUMULATEDCOMMISSIONRECORD._options = None
  _VALIDATORACCUMULATEDCOMMISSIONRECORD._serialized_options = b'\350\240\037\000\210\240\037\000'
  _VALIDATORHISTORICALREWARDSRECORD.fields_by_name['validator_address']._options = None
  _VALIDATORHISTORICALREWARDSRECORD.fields_by_name['validator_address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _VALIDATORHISTORICALREWARDSRECORD.fields_by_name['rewards']._options = None
  _VALIDATORHISTORICALREWARDSRECORD.fields_by_name['rewards']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _VALIDATORHISTORICALREWARDSRECORD._options = None
  _VALIDATORHISTORICALREWARDSRECORD._serialized_options = b'\350\240\037\000\210\240\037\000'
  _VALIDATORCURRENTREWARDSRECORD.fields_by_name['validator_address']._options = None
  _VALIDATORCURRENTREWARDSRECORD.fields_by_name['validator_address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _VALIDATORCURRENTREWARDSRECORD.fields_by_name['rewards']._options = None
  _VALIDATORCURRENTREWARDSRECORD.fields_by_name['rewards']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _VALIDATORCURRENTREWARDSRECORD._options = None
  _VALIDATORCURRENTREWARDSRECORD._serialized_options = b'\350\240\037\000\210\240\037\000'
  _DELEGATORSTARTINGINFORECORD.fields_by_name['delegator_address']._options = None
  _DELEGATORSTARTINGINFORECORD.fields_by_name['delegator_address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _DELEGATORSTARTINGINFORECORD.fields_by_name['validator_address']._options = None
  _DELEGATORSTARTINGINFORECORD.fields_by_name['validator_address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _DELEGATORSTARTINGINFORECORD.fields_by_name['starting_info']._options = None
  _DELEGATORSTARTINGINFORECORD.fields_by_name['starting_info']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _DELEGATORSTARTINGINFORECORD._options = None
  _DELEGATORSTARTINGINFORECORD._serialized_options = b'\350\240\037\000\210\240\037\000'
  _VALIDATORSLASHEVENTRECORD.fields_by_name['validator_address']._options = None
  _VALIDATORSLASHEVENTRECORD.fields_by_name['validator_address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _VALIDATORSLASHEVENTRECORD.fields_by_name['validator_slash_event']._options = None
  _VALIDATORSLASHEVENTRECORD.fields_by_name['validator_slash_event']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _VALIDATORSLASHEVENTRECORD._options = None
  _VALIDATORSLASHEVENTRECORD._serialized_options = b'\350\240\037\000\210\240\037\000'
  _GENESISSTATE.fields_by_name['params']._options = None
  _GENESISSTATE.fields_by_name['params']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _GENESISSTATE.fields_by_name['fee_pool']._options = None
  _GENESISSTATE.fields_by_name['fee_pool']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _GENESISSTATE.fields_by_name['delegator_withdraw_infos']._options = None
  _GENESISSTATE.fields_by_name['delegator_withdraw_infos']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _GENESISSTATE.fields_by_name['previous_proposer']._options = None
  _GENESISSTATE.fields_by_name['previous_proposer']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _GENESISSTATE.fields_by_name['outstanding_rewards']._options = None
  _GENESISSTATE.fields_by_name['outstanding_rewards']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _GENESISSTATE.fields_by_name['validator_accumulated_commissions']._options = None
  _GENESISSTATE.fields_by_name['validator_accumulated_commissions']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _GENESISSTATE.fields_by_name['validator_historical_rewards']._options = None
  _GENESISSTATE.fields_by_name['validator_historical_rewards']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _GENESISSTATE.fields_by_name['validator_current_rewards']._options = None
  _GENESISSTATE.fields_by_name['validator_current_rewards']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _GENESISSTATE.fields_by_name['delegator_starting_infos']._options = None
  _GENESISSTATE.fields_by_name['delegator_starting_infos']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _GENESISSTATE.fields_by_name['validator_slash_events']._options = None
  _GENESISSTATE.fields_by_name['validator_slash_events']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _GENESISSTATE._options = None
  _GENESISSTATE._serialized_options = b'\350\240\037\000\210\240\037\000'
  _DELEGATORWITHDRAWINFO._serialized_start=223
  _DELEGATORWITHDRAWINFO._serialized_end=361
  _VALIDATOROUTSTANDINGREWARDSRECORD._serialized_start=364
  _VALIDATOROUTSTANDINGREWARDSRECORD._serialized_end=579
  _VALIDATORACCUMULATEDCOMMISSIONRECORD._serialized_start=582
  _VALIDATORACCUMULATEDCOMMISSIONRECORD._serialized_end=776
  _VALIDATORHISTORICALREWARDSRECORD._serialized_start=779
  _VALIDATORHISTORICALREWARDSRECORD._serialized_end=977
  _VALIDATORCURRENTREWARDSRECORD._serialized_start=980
  _VALIDATORCURRENTREWARDSRECORD._serialized_end=1156
  _DELEGATORSTARTINGINFORECORD._serialized_start=1159
  _DELEGATORSTARTINGINFORECORD._serialized_end=1390
  _VALIDATORSLASHEVENTRECORD._serialized_start=1393
  _VALIDATORSLASHEVENTRECORD._serialized_end=1607
  _GENESISSTATE._serialized_start=1610
  _GENESISSTATE._serialized_end=2560
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/params/v1beta1/query.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from cosmos.params.v1beta1 import params_pb2 as cosmos_dot_params_dot_v1beta1_dot_params__pb2
from amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!cosmos/params/v1beta1/query.proto\x12\x15\x63osmos.params.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a\"cosmos/params/v1beta1/params.proto\x1a\x11\x61mino/amino.proto\"3\n\x12QueryParamsRequest\x12\x10\n\x08subspace\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\"S\n\x13QueryParamsResponse\x12<\n\x05param\x18\x01 \x01(\x0b\x32\".cosmos.params.v1beta1.ParamChangeB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"\x17\n\x15QuerySubspacesRequest\"L\n\x16QuerySubspacesResponse\x12\x32\n\tsubspaces\x18\x01 \x03(\x0b\x32\x1f.cosmos.params.v1beta1.Subspace\"*\n\x08Subspace\x12\x10\n\x08subspace\x18\x01 \x01(\t\x12\x0c\n\x04keys\x18\x02 \x03(\t2\xa5\x02\n\x05Query\x12\x86\x01\n\x06Params\x12).cosmos.params.v1beta1.QueryParamsRequest\x1a*.cosmos.params.v1beta1.QueryParamsResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/cosmos/params/v1beta1/params\x12\x92\x01\n\tSubspaces\x12,.cosmos.params.v1beta1.QuerySubspacesRequest\x1a-.cosmos.params.v1beta1.QuerySubspacesResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /cosmos/params/v1beta1/subspacesB6Z4github.com/cosmos/cosmos-sdk/x/params/types/proposalb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.params.v1beta1.query_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z4github.com/cosmos/cosmos-sdk/x/params/types/proposal'
  _QUERYPARAMSRESPONSE.fields_by_name['param']._options = None
  _QUERYPARAMSRESPONSE.fields_by_name['param']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _QUERY.methods_by_name['Params']._options = None
  _QUERY.methods_by_name['Params']._serialized_options = b'\202\323\344\223\002\037\022\035/cosmos/params/v1beta1/params'
  _QUERY.methods_by_name['Subspaces']._options = None
  _QUERY.methods_by_name['Subspaces']._serialized_options = b'\202\323\344\223\002\"\022 /cosmos/params/v1beta1/subspaces'
  _QUERYPARAMSREQUEST._serialized_start=167
  _QUERYPARAMSREQUEST._serialized_end=218
  _QUERYPARAMSRESPONSE._serialized_start=220
  _QUERYPARAMSRESPONSE._serialized_end=303
  _QUERYSUBSPACESREQUEST._serialized_start=305
  _QUERYSUBSPACESREQUEST._serialized_end=328
  _QUERYSUBSPACESRESPONSE._serialized_start=330
  _QUERYSUBSPACESRESPONSE._serialized_end=406
  _SUBSPACE._serialized_start=408
  _SUBSPACE._serialized_end=450
  _QUERY._serialized_start=453
  _QUERY._serialized_end=746
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/applications/interchain_accounts/controller/v1/controller.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCibc/applications/interchain_accounts/controller/v1/controller.proto\x12\x32ibc.applications.interchain_accounts.controller.v1\"$\n\x06Params\x12\x1a\n\x12\x63ontroller_enabled\x18\x01 \x01(\x08\x42RZPgithub.com/cosmos/ibc-go/v7/modules/apps/27-interchain-accounts/controller/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.applications.interchain_accounts.controller.v1.controller_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZPgithub.com/cosmos/ibc-go/v7/modules/apps/27-interchain-accounts/controller/types'
  _PARAMS._serialized_start=123
  _PARAMS._serialized_end=159
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/lightclients/solomachine/v3/solomachine.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1ibc/lightclients/solomachine/v3/solomachine.proto\x12\x1fibc.lightclients.solomachine.v3\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto\"\x82\x01\n\x0b\x43lientState\x12\x10\n\x08sequence\x18\x01 \x01(\x04\x12\x11\n\tis_frozen\x18\x02 \x01(\x08\x12H\n\x0f\x63onsensus_state\x18\x03 \x01(\x0b\x32/.ibc.lightclients.solomachine.v3.ConsensusState:\x04\x88\xa0\x1f\x00\"h\n\x0e\x43onsensusState\x12(\n\npublic_key\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x13\n\x0b\x64iversifier\x18\x02 \x01(\t\x12\x11\n\ttimestamp\x18\x03 \x01(\x04:\x04\x88\xa0\x1f\x00\"{\n\x06Header\x12\x11\n\ttimestamp\x18\x01 \x01(\x04\x12\x11\n\tsignature\x18\x02 \x01(\x0c\x12,\n\x0enew_public_key\x18\x03 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x17\n\x0fnew_diversifier\x18\x04 \x01(\t:\x04\x88\xa0\x1f\x00\"\xba\x01\n\x0cMisbehaviour\x12\x10\n\x08sequence\x18\x01 \x01(\x04\x12H\n\rsignature_one\x18\x02 \x01(\x0b\x32\x31.ibc.lightclients.solomachine.v3.SignatureAndData\x12H\n\rsignature_two\x18\x03 \x01(\x0b\x32\x31.ibc.lightclients.solomachine.v3.SignatureAndData:\x04\x88\xa0\x1f\x00\"Z\n\x10SignatureAndData\x12\x11\n\tsignature\x18\x01 \x01(\x0c\x12\x0c\n\x04path\x18\x02 \x01(\x0c\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c\x12\x11\n\ttimestamp\x18\x04 \x01(\x04:\x04\x88\xa0\x1f\x00\"K\n\x18TimestampedSignatureData\x12\x16\n\x0esignature_data\x18\x01 \x01(\x0c\x12\x11\n\ttimestamp\x18\x02 \x01(\x04:\x04\x88\xa0\x1f\x00\"g\n\tSignBytes\x12\x10\n\x08sequence\x18\x01 \x01(\x04\x12\x11\n\ttimestamp\x18\x02 \x01(\x04\x12\x13\n\x0b\x64iversifier\x18\x03 \x01(\t\x12\x0c\n\x04path\x18\x04 \x01(\x0c\x12\x0c\n\x04\x64\x61ta\x18\x05 \x01(\x0c:\x04\x88\xa0\x1f\x00\"V\n\nHeaderData\x12)\n\x0bnew_pub_key\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x17\n\x0fnew_diversifier\x18\x02 \x01(\t:\x04\x88\xa0\x1f\x00\x42NZLgithub.com/cosmos/ibc-go/v7/modules/light-clients/06-solomachine;solomachineb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.lightclients.solomachine.v3.solomachine_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZLgithub.com/cosmos/ibc-go/v7/modules/light-clients/06-solomachine;solomachine'
  _CLIENTSTATE._options = None
  _CLIENTSTATE._serialized_options = b'\210\240\037\000'
  _CONSENSUSSTATE._options = None
  _CONSENSUSSTATE._serialized_options = b'\210\240\037\000'
  _HEADER._options = None
  _HEADER._serialized_options = b'\210\240\037\000'
  _MISBEHAVIOUR._options = None
  _MISBEHAVIOUR._serialized_options = b'\210\240\037\000'
  _SIGNATUREANDDATA._options = None
  _SIGNATUREANDDATA._serialized_options = b'\210\240\037\000'
  _TIMESTAMPEDSIGNATUREDATA._options = None
  _TIMESTAMPEDSIGNATUREDATA._serialized_options = b'\210\240\037\000'
  _SIGNBYTES._options = None
  _SIGNBYTES._serialized_options = b'\210\240\037\000'
  _HEADERDATA._options = None
  _HEADERDATA._serialized_options = b'\210\240\037\000'
  _CLIENTSTATE._serialized_start=136
  _CLIENTSTATE._serialized_end=266
  _CONSENSUSSTATE._serialized_start=268
  _CONSENSUSSTATE._serialized_end=372
  _HEADER._serialized_start=374
  _HEADER._serialized_end=497
  _MISBEHAVIOUR._serialized_start=500
  _MISBEHAVIOUR._serialized_end=686
  _SIGNATUREANDDATA._serialized_start=688
  _SIGNATUREANDDATA._serialized_end=778
  _TIMESTAMPEDSIGNATUREDATA._serialized_start=780
  _TIMESTAMPEDSIGNATUREDATA._serialized_end=855
  _SIGNBYTES._serialized_start=857
  _SIGNBYTES._serialized_end=960
  _HEADERDATA._serialized_start=962
  _HEADERDATA._serialized_end=1048
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: capability/v1/genesis.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from capability.v1 import capability_pb2 as capability_dot_v1_dot_capability__pb2
from amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x63\x61pability/v1/genesis.proto\x12\rcapability.v1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63\x61pability/v1/capability.proto\x1a\x11\x61mino/amino.proto\"`\n\rGenesisOwners\x12\r\n\x05index\x18\x01 \x01(\x04\x12@\n\x0cindex_owners\x18\x02 \x01(\x0b\x32\x1f.capability.v1.CapabilityOwnersB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"V\n\x0cGenesisState\x12\r\n\x05index\x18\x01 \x01(\x04\x12\x37\n\x06owners\x18\x02 \x03(\x0b\x32\x1c.capability.v1.GenesisOwnersB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x42\x33Z1github.com/cosmos/ibc-go/modules/capability/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'capability.v1.genesis_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1github.com/cosmos/ibc-go/modules/capability/types'
  _GENESISOWNERS.fields_by_name['index_owners']._options = None
  _GENESISOWNERS.fields_by_name['index_owners']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _GENESISSTATE.fields_by_name['owners']._options = None
  _GENESISSTATE.fields_by_name['owners']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _GENESISOWNERS._serialized_start=119
  _GENESISOWNERS._serialized_end=215
  _GENESISSTATE._serialized_start=217
  _GENESISSTATE._serialized_end=303
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/core/client/v1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from ibc.core.client.v1 import client_pb2 as ibc_dot_core_dot_client_dot_v1_dot_client__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bibc/core/client/v1/tx.proto\x12\x12ibc.core.client.v1\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto\x1a\x1fibc/core/client/v1/client.proto\"\x91\x01\n\x0fMsgCreateClient\x12*\n\x0c\x63lient_state\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\x12-\n\x0f\x63onsensus_state\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x0e\n\x06signer\x18\x03 \x01(\t:\x13\x82\xe7\xb0*\x06signer\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x19\n\x17MsgCreateClientResponse\"w\n\x0fMsgUpdateClient\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12,\n\x0e\x63lient_message\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x0e\n\x06signer\x18\x03 \x01(\t:\x13\x82\xe7\xb0*\x06signer\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x19\n\x17MsgUpdateClientResponse\"\xea\x01\n\x10MsgUpgradeClient\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12*\n\x0c\x63lient_state\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\x12-\n\x0f\x63onsensus_state\x18\x03 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x1c\n\x14proof_upgrade_client\x18\x04 \x01(\x0c\x12%\n\x1dproof_upgrade_consensus_state\x18\x05 \x01(\x0c\x12\x0e\n\x06signer\x18\x06 \x01(\t:\x13\x82\xe7\xb0*\x06signer\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x1a\n\x18MsgUpgradeClientResponse\"\x87\x01\n\x15MsgSubmitMisbehaviour\x12\x15\n\tclient_id\x18\x01 \x01(\tB\x02\x18\x01\x12.\n\x0cmisbehaviour\x18\x02 \x01(\x0b\x32\x14.google.protobuf.AnyB\x02\x18\x01\x12\x12\n\x06signer\x18\x03 \x01(\tB\x02\x18\x01:\x13\x82\xe7\xb0*\x06signer\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x1f\n\x1dMsgSubmitMisbehaviourResponse\"f\n\x0fMsgUpdateParams\x12\x11\n\tauthority\x18\x01 \x01(\t\x12\x30\n\x06params\x18\x02 \x01(\x0b\x32\x1a.ibc.core.client.v1.ParamsB\x04\xc8\xde\x1f\x00:\x0e\x82\xe7\xb0*\tauthority\"\x19\n\x17MsgUpdateParamsResponse2\x91\x04\n\x03Msg\x12`\n\x0c\x43reateClient\x12#.ibc.core.client.v1.MsgCreateClient\x1a+.ibc.core.client.v1.MsgCreateClientResponse\x12`\n\x0cUpdateClient\x12#.ibc.core.client.v1.MsgUpdateClient\x1a+.ibc.core.client.v1.MsgUpdateClientResponse\x12\x63\n\rUpgradeClient\x12$.ibc.core.client.v1.MsgUpgradeClient\x1a,.ibc.core.client.v1.MsgUpgradeClientResponse\x12r\n\x12SubmitMisbehaviour\x12).ibc.core.client.v1.MsgSubmitMisbehaviour\x1a\x31.ibc.core.client.v1.MsgSubmitMisbehaviourResponse\x12\x66\n\x12UpdateClientParams\x12#.ibc.core.client.v1.MsgUpdateParams\x1a+.ibc.core.client.v1.MsgUpdateParamsResponse\x1a\x05\x80\xe7\xb0*\x01\x42:Z8github.com/cosmos/ibc-go/v7/modules/core/02-client/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.core.client.v1.tx_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z8github.com/cosmos/ibc-go/v7/modules/core/02-client/types'
  _MSGCREATECLIENT._options = None
  _MSGCREATECLIENT._serialized_options = b'\202\347\260*\006signer\350\240\037\000\210\240\037\000'
  _MSGUPDATECLIENT._options = None
  _MSGUPDATECLIENT._serialized_options = b'\202\347\260*\006signer\350\240\037\000\210\240\037\000'
  _MSGUPGRADECLIENT._options = None
  _MSGUPGRADECLIENT._serialized_options = b'\202\347\260*\006signer\350\240\037\000\210\240\037\000'
  _MSGSUBMITMISBEHAVIOUR.fields_by_name['client_id']._options = None
  _MSGSUBMITMISBEHAVIOUR.fields_by_name['client_id']._serialized_options = b'\030\001'
  _MSGSUBMITMISBEHAVIOUR.fields_by_name['misbehaviour']._options = None
  _MSGSUBMITMISBEHAVIOUR.fields_by_name['misbehaviour']._serialized_options = b'\030\001'
  _MSGSUBMITMISBEHAVIOUR.fields_by_name['signer']._options = None
  _MSGSUBMITMISBEHAVIOUR.fields_by_name['signer']._serialized_options = b'\030\001'
  _MSGSUBMITMISBEHAVIOUR._options = None
  _MSGSUBMITMISBEHAVIOUR._serialized_options = b'\202\347\260*\006signer\350\240\037\000\210\240\037\000'
  _MSGUPDATEPARAMS.fields_by_name['params']._options = None
  _MSGUPDATEPARAMS.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _MSGUPDATEPARAMS._options = None
  _MSGUPDATEPARAMS._serialized_options = b'\202\347\260*\tauthority'
  _MSG._options = None
  _MSG._serialized_options = b'\200\347\260*\001'
  _MSGCREATECLIENT._serialized_start=159
  _MSGCREATECLIENT._serialized_end=304
  _MSGCREATECLIENTRESPONSE._serialized_start=306
  _MSGCREATECLIENTRESPONSE._serialized_end=331
  _MSGUPDATECLIENT._serialized_start=333
  _MSGUPDATECLIENT._serialized_end=452
  _MSGUPDATECLIENTRESPONSE._serialized_start=454
  _MSGUPDATECLIENTRESPONSE._serialized_end=479
  _MSGUPGRADECLIENT._serialized_start=482
  _MSGUPGRADECLIENT._serialized_end=716
  _MSGUPGRADECLIENTRESPONSE._serialized_start=718
  _MSGUPGRADECLIENTRESPONSE._serialized_end=744
  _MSGSUBMITMISBEHAVIOUR._serialized_start=747
  _MSGSUBMITMISBEHAVIOUR._serialized_end=882
  _MSGSUBMITMISBEHAVIOURRESPONSE._serialized_start=884
  _MSGSUBMITMISBEHAVIOURRESPONSE._serialized_end=915
  _MSGUPDATEPARAMS._serialized_start=917
  _MSGUPDATEPARAMS._serialized_end=1019
  _MSGUPDATEPARAMSRESPONSE._serialized_start=1021
  _MSGUPDATEPARAMSRESPONSE._serialized_end=1046
  _MSG._serialized_start=1049
  _MSG._serialized_end=1578
# @@protoc_insertion_point(module_scope)



from pyinjective import PrivateKey
from pyinjective.composer import Composer
from pyinjective.constant import Network
from pyinjective.orderhash import OrderHashManager


class TestOrderHashManager:

    def test_spot_order_hash(self, requests_mock):
        network = Network.devnet()
        composer = Composer(network=network.string())
        priv_key = PrivateKey.from_mnemonic("test one few words")
        pub_key = priv_key.to_public_key()
        address = pub_key.to_address()

        subaccount_id = address.get_subaccount_id(index=0)

        url = network.lcd_endpoint + "/injective/exchange/v1beta1/exchange/" + subaccount_id
        requests_mock.get(url, json={"nonce": 0})
        order_hash_manager = OrderHashManager(
            address=address,
            network=network,
            subaccount_indexes=[0]
        )

        spot_market_id = "0xa508cb32923323679f29a032c70342c147c17d0145625922b0ef22e955c844c0"
        fee_recipient = "inj1hkhdaj2a2clmq5jq6mspsggqs32vynpk228q3r"

        spot_orders = [
            composer.SpotOrder(
                market_id=spot_market_id,
                subaccount_id=subaccount_id,
                fee_recipient=fee_recipient,
                price=0.524,
                quantity=0.01,
                is_buy=True,
                is_po=False
            ),
            composer.SpotOrder(
                market_id=spot_market_id,
                subaccount_id=subaccount_id,
                fee_recipient=fee_recipient,
                price=27.92,
                quantity=0.01,
                is_buy=False,
                is_po=False
            ),
        ]

        order_hashes_response = order_hash_manager.compute_order_hashes(
            spot_orders=spot_orders,
            derivative_orders=[],
            subaccount_index=0
        )

        assert (len(order_hashes_response.spot) == 2)
        assert (len(order_hashes_response.derivative) == 0)
        assert (order_hashes_response.spot[0] == "0x6b1e4d1fb3012735dd5e386175eb4541c024e0d8dbfeb452767b973d70ae0924")
        assert (order_hashes_response.spot[1] == "0xb36146f913955d989269732d167ec554e6d0d544411d82d7f86aef18350b252b")



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/applications/interchain_accounts/host/v1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from ibc.applications.interchain_accounts.host.v1 import host_pb2 as ibc_dot_applications_dot_interchain__accounts_dot_host_dot_v1_dot_host__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5ibc/applications/interchain_accounts/host/v1/tx.proto\x12,ibc.applications.interchain_accounts.host.v1\x1a\x14gogoproto/gogo.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x37ibc/applications/interchain_accounts/host/v1/host.proto\"\x80\x01\n\x0fMsgUpdateParams\x12\x11\n\tauthority\x18\x01 \x01(\t\x12J\n\x06params\x18\x02 \x01(\x0b\x32\x34.ibc.applications.interchain_accounts.host.v1.ParamsB\x04\xc8\xde\x1f\x00:\x0e\x82\xe7\xb0*\tauthority\"\x19\n\x17MsgUpdateParamsResponse2\xa3\x01\n\x03Msg\x12\x94\x01\n\x0cUpdateParams\x12=.ibc.applications.interchain_accounts.host.v1.MsgUpdateParams\x1a\x45.ibc.applications.interchain_accounts.host.v1.MsgUpdateParamsResponse\x1a\x05\x80\xe7\xb0*\x01\x42LZJgithub.com/cosmos/ibc-go/v7/modules/apps/27-interchain-accounts/host/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.applications.interchain_accounts.host.v1.tx_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZJgithub.com/cosmos/ibc-go/v7/modules/apps/27-interchain-accounts/host/types'
  _MSGUPDATEPARAMS.fields_by_name['params']._options = None
  _MSGUPDATEPARAMS.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _MSGUPDATEPARAMS._options = None
  _MSGUPDATEPARAMS._serialized_options = b'\202\347\260*\tauthority'
  _MSG._options = None
  _MSG._serialized_options = b'\200\347\260*\001'
  _MSGUPDATEPARAMS._serialized_start=208
  _MSGUPDATEPARAMS._serialized_end=336
  _MSGUPDATEPARAMSRESPONSE._serialized_start=338
  _MSGUPDATEPARAMSRESPONSE._serialized_end=363
  _MSG._serialized_start=366
  _MSG._serialized_end=529
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/vesting/v1beta1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from cosmos.vesting.v1beta1 import vesting_pb2 as cosmos_dot_vesting_dot_v1beta1_dot_vesting__pb2
from cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x63osmos/vesting/v1beta1/tx.proto\x12\x16\x63osmos.vesting.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a$cosmos/vesting/v1beta1/vesting.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x11\x61mino/amino.proto\"\xba\x02\n\x17MsgCreateVestingAccount\x12.\n\x0c\x66rom_address\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12,\n\nto_address\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12`\n\x06\x61mount\x18\x03 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB5\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12\x10\n\x08\x65nd_time\x18\x04 \x01(\x03\x12\x0f\n\x07\x64\x65layed\x18\x05 \x01(\x08:<\x82\xe7\xb0*\x0c\x66rom_address\x8a\xe7\xb0*\"cosmos-sdk/MsgCreateVestingAccount\xe8\xa0\x1f\x01\"!\n\x1fMsgCreateVestingAccountResponse\"\x9e\x02\n\x1fMsgCreatePermanentLockedAccount\x12-\n\x0c\x66rom_address\x18\x01 \x01(\tB\x17\xf2\xde\x1f\x13yaml:\"from_address\"\x12)\n\nto_address\x18\x02 \x01(\tB\x15\xf2\xde\x1f\x11yaml:\"to_address\"\x12`\n\x06\x61mount\x18\x03 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB5\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins:?\x82\xe7\xb0*\x0c\x66rom_address\x8a\xe7\xb0*%cosmos-sdk/MsgCreatePermLockedAccount\xe8\xa0\x1f\x01\")\n\'MsgCreatePermanentLockedAccountResponse\"\xe9\x01\n\x1fMsgCreatePeriodicVestingAccount\x12\x14\n\x0c\x66rom_address\x18\x01 \x01(\t\x12\x12\n\nto_address\x18\x02 \x01(\t\x12\x12\n\nstart_time\x18\x03 \x01(\x03\x12\x42\n\x0fvesting_periods\x18\x04 \x03(\x0b\x32\x1e.cosmos.vesting.v1beta1.PeriodB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01:D\x82\xe7\xb0*\x0c\x66rom_address\x8a\xe7\xb0**cosmos-sdk/MsgCreatePeriodicVestingAccount\xe8\xa0\x1f\x00\")\n\'MsgCreatePeriodicVestingAccountResponse2\xc5\x03\n\x03Msg\x12\x80\x01\n\x14\x43reateVestingAccount\x12/.cosmos.vesting.v1beta1.MsgCreateVestingAccount\x1a\x37.cosmos.vesting.v1beta1.MsgCreateVestingAccountResponse\x12\x98\x01\n\x1c\x43reatePermanentLockedAccount\x12\x37.cosmos.vesting.v1beta1.MsgCreatePermanentLockedAccount\x1a?.cosmos.vesting.v1beta1.MsgCreatePermanentLockedAccountResponse\x12\x98\x01\n\x1c\x43reatePeriodicVestingAccount\x12\x37.cosmos.vesting.v1beta1.MsgCreatePeriodicVestingAccount\x1a?.cosmos.vesting.v1beta1.MsgCreatePeriodicVestingAccountResponse\x1a\x05\x80\xe7\xb0*\x01\x42\x33Z1github.com/cosmos/cosmos-sdk/x/auth/vesting/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.vesting.v1beta1.tx_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1github.com/cosmos/cosmos-sdk/x/auth/vesting/types'
  _MSGCREATEVESTINGACCOUNT.fields_by_name['from_address']._options = None
  _MSGCREATEVESTINGACCOUNT.fields_by_name['from_address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _MSGCREATEVESTINGACCOUNT.fields_by_name['to_address']._options = None
  _MSGCREATEVESTINGACCOUNT.fields_by_name['to_address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _MSGCREATEVESTINGACCOUNT.fields_by_name['amount']._options = None
  _MSGCREATEVESTINGACCOUNT.fields_by_name['amount']._serialized_options = b'\310\336\037\000\250\347\260*\001\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _MSGCREATEVESTINGACCOUNT._options = None
  _MSGCREATEVESTINGACCOUNT._serialized_options = b'\202\347\260*\014from_address\212\347\260*\"cosmos-sdk/MsgCreateVestingAccount\350\240\037\001'
  _MSGCREATEPERMANENTLOCKEDACCOUNT.fields_by_name['from_address']._options = None
  _MSGCREATEPERMANENTLOCKEDACCOUNT.fields_by_name['from_address']._serialized_options = b'\362\336\037\023yaml:\"from_address\"'
  _MSGCREATEPERMANENTLOCKEDACCOUNT.fields_by_name['to_address']._options = None
  _MSGCREATEPERMANENTLOCKEDACCOUNT.fields_by_name['to_address']._serialized_options = b'\362\336\037\021yaml:\"to_address\"'
  _MSGCREATEPERMANENTLOCKEDACCOUNT.fields_by_name['amount']._options = None
  _MSGCREATEPERMANENTLOCKEDACCOUNT.fields_by_name['amount']._serialized_options = b'\310\336\037\000\250\347\260*\001\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _MSGCREATEPERMANENTLOCKEDACCOUNT._options = None
  _MSGCREATEPERMANENTLOCKEDACCOUNT._serialized_options = b'\202\347\260*\014from_address\212\347\260*%cosmos-sdk/MsgCreatePermLockedAccount\350\240\037\001'
  _MSGCREATEPERIODICVESTINGACCOUNT.fields_by_name['vesting_periods']._options = None
  _MSGCREATEPERIODICVESTINGACCOUNT.fields_by_name['vesting_periods']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _MSGCREATEPERIODICVESTINGACCOUNT._options = None
  _MSGCREATEPERIODICVESTINGACCOUNT._serialized_options = b'\202\347\260*\014from_address\212\347\260**cosmos-sdk/MsgCreatePeriodicVestingAccount\350\240\037\000'
  _MSG._options = None
  _MSG._serialized_options = b'\200\347\260*\001'
  _MSGCREATEVESTINGACCOUNT._serialized_start=223
  _MSGCREATEVESTINGACCOUNT._serialized_end=537
  _MSGCREATEVESTINGACCOUNTRESPONSE._serialized_start=539
  _MSGCREATEVESTINGACCOUNTRESPONSE._serialized_end=572
  _MSGCREATEPERMANENTLOCKEDACCOUNT._serialized_start=575
  _MSGCREATEPERMANENTLOCKEDACCOUNT._serialized_end=861
  _MSGCREATEPERMANENTLOCKEDACCOUNTRESPONSE._serialized_start=863
  _MSGCREATEPERMANENTLOCKEDACCOUNTRESPONSE._serialized_end=904
  _MSGCREATEPERIODICVESTINGACCOUNT._serialized_start=907
  _MSGCREATEPERIODICVESTINGACCOUNT._serialized_end=1140
  _MSGCREATEPERIODICVESTINGACCOUNTRESPONSE._serialized_start=1142
  _MSGCREATEPERIODICVESTINGACCOUNTRESPONSE._serialized_end=1183
  _MSG._serialized_start=1186
  _MSG._serialized_end=1639
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/slashing/v1beta1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.slashing.v1beta1 import slashing_pb2 as cosmos_dot_slashing_dot_v1beta1_dot_slashing__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n cosmos/slashing/v1beta1/tx.proto\x12\x17\x63osmos.slashing.v1beta1\x1a\x14gogoproto/gogo.proto\x1a&cosmos/slashing/v1beta1/slashing.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x11\x61mino/amino.proto\"\x8f\x01\n\tMsgUnjail\x12L\n\x0evalidator_addr\x18\x01 \x01(\tB4\xd2\xb4-\x14\x63osmos.AddressString\xea\xde\x1f\x07\x61\x64\x64ress\xa2\xe7\xb0*\x07\x61\x64\x64ress\xa8\xe7\xb0*\x01:4\x82\xe7\xb0*\x0evalidator_addr\x8a\xe7\xb0*\x14\x63osmos-sdk/MsgUnjail\x88\xa0\x1f\x00\x98\xa0\x1f\x01\"\x13\n\x11MsgUnjailResponse\"\xb4\x01\n\x0fMsgUpdateParams\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12:\n\x06params\x18\x02 \x01(\x0b\x32\x1f.cosmos.slashing.v1beta1.ParamsB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01:8\x82\xe7\xb0*\tauthority\x8a\xe7\xb0*%cosmos-sdk/x/slashing/MsgUpdateParams\"\x19\n\x17MsgUpdateParamsResponse2\xd2\x01\n\x03Msg\x12X\n\x06Unjail\x12\".cosmos.slashing.v1beta1.MsgUnjail\x1a*.cosmos.slashing.v1beta1.MsgUnjailResponse\x12j\n\x0cUpdateParams\x12(.cosmos.slashing.v1beta1.MsgUpdateParams\x1a\x30.cosmos.slashing.v1beta1.MsgUpdateParamsResponse\x1a\x05\x80\xe7\xb0*\x01\x42\x33Z-github.com/cosmos/cosmos-sdk/x/slashing/types\xa8\xe2\x1e\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.slashing.v1beta1.tx_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/cosmos/cosmos-sdk/x/slashing/types\250\342\036\001'
  _MSGUNJAIL.fields_by_name['validator_addr']._options = None
  _MSGUNJAIL.fields_by_name['validator_addr']._serialized_options = b'\322\264-\024cosmos.AddressString\352\336\037\007address\242\347\260*\007address\250\347\260*\001'
  _MSGUNJAIL._options = None
  _MSGUNJAIL._serialized_options = b'\202\347\260*\016validator_addr\212\347\260*\024cosmos-sdk/MsgUnjail\210\240\037\000\230\240\037\001'
  _MSGUPDATEPARAMS.fields_by_name['authority']._options = None
  _MSGUPDATEPARAMS.fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _MSGUPDATEPARAMS.fields_by_name['params']._options = None
  _MSGUPDATEPARAMS.fields_by_name['params']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _MSGUPDATEPARAMS._options = None
  _MSGUPDATEPARAMS._serialized_options = b'\202\347\260*\tauthority\212\347\260*%cosmos-sdk/x/slashing/MsgUpdateParams'
  _MSG._options = None
  _MSG._serialized_options = b'\200\347\260*\001'
  _MSGUNJAIL._serialized_start=195
  _MSGUNJAIL._serialized_end=338
  _MSGUNJAILRESPONSE._serialized_start=340
  _MSGUNJAILRESPONSE._serialized_end=359
  _MSGUPDATEPARAMS._serialized_start=362
  _MSGUPDATEPARAMS._serialized_end=542
  _MSGUPDATEPARAMSRESPONSE._serialized_start=544
  _MSGUPDATEPARAMSRESPONSE._serialized_end=569
  _MSG._serialized_start=572
  _MSG._serialized_end=782
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/core/commitment/v1/commitment.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.ics23.v1 import proofs_pb2 as cosmos_dot_ics23_dot_v1_dot_proofs__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'ibc/core/commitment/v1/commitment.proto\x12\x16ibc.core.commitment.v1\x1a\x14gogoproto/gogo.proto\x1a\x1c\x63osmos/ics23/v1/proofs.proto\" \n\nMerkleRoot\x12\x0c\n\x04hash\x18\x01 \x01(\x0c:\x04\x88\xa0\x1f\x00\"\"\n\x0cMerklePrefix\x12\x12\n\nkey_prefix\x18\x01 \x01(\x0c\"$\n\nMerklePath\x12\x10\n\x08key_path\x18\x01 \x03(\t:\x04\x98\xa0\x1f\x00\"?\n\x0bMerkleProof\x12\x30\n\x06proofs\x18\x01 \x03(\x0b\x32 .cosmos.ics23.v1.CommitmentProofB>Z<github.com/cosmos/ibc-go/v7/modules/core/23-commitment/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.core.commitment.v1.commitment_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z<github.com/cosmos/ibc-go/v7/modules/core/23-commitment/types'
  _MERKLEROOT._options = None
  _MERKLEROOT._serialized_options = b'\210\240\037\000'
  _MERKLEPATH._options = None
  _MERKLEPATH._serialized_options = b'\230\240\037\000'
  _MERKLEROOT._serialized_start=119
  _MERKLEROOT._serialized_end=151
  _MERKLEPREFIX._serialized_start=153
  _MERKLEPREFIX._serialized_end=187
  _MERKLEPATH._serialized_start=189
  _MERKLEPATH._serialized_end=225
  _MERKLEPROOF._serialized_start=227
  _MERKLEPROOF._serialized_end=290
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/applications/transfer/v1/genesis.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ibc.applications.transfer.v1 import transfer_pb2 as ibc_dot_applications_dot_transfer_dot_v1_dot_transfer__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*ibc/applications/transfer/v1/genesis.proto\x12\x1cibc.applications.transfer.v1\x1a+ibc/applications/transfer/v1/transfer.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x14gogoproto/gogo.proto\"\x90\x02\n\x0cGenesisState\x12\x0f\n\x07port_id\x18\x01 \x01(\t\x12N\n\x0c\x64\x65nom_traces\x18\x02 \x03(\x0b\x32(.ibc.applications.transfer.v1.DenomTraceB\x0e\xaa\xdf\x1f\x06Traces\xc8\xde\x1f\x00\x12:\n\x06params\x18\x03 \x01(\x0b\x32$.ibc.applications.transfer.v1.ParamsB\x04\xc8\xde\x1f\x00\x12\x63\n\x0etotal_escrowed\x18\x04 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\xc8\xde\x1f\x00\x42\x39Z7github.com/cosmos/ibc-go/v7/modules/apps/transfer/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.applications.transfer.v1.genesis_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z7github.com/cosmos/ibc-go/v7/modules/apps/transfer/types'
  _GENESISSTATE.fields_by_name['denom_traces']._options = None
  _GENESISSTATE.fields_by_name['denom_traces']._serialized_options = b'\252\337\037\006Traces\310\336\037\000'
  _GENESISSTATE.fields_by_name['params']._options = None
  _GENESISSTATE.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _GENESISSTATE.fields_by_name['total_escrowed']._options = None
  _GENESISSTATE.fields_by_name['total_escrowed']._serialized_options = b'\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\310\336\037\000'
  _GENESISSTATE._serialized_start=176
  _GENESISSTATE._serialized_end=448
# @@protoc_insertion_point(module_scope)
